/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_Nr778c4c);
  numBytes += sLine_init(&sLine_bqJlyGNs);
  numBytes += sLine_init(&sLine_5O11rrrH);
  numBytes += sLine_init(&sLine_KKhe5vKv);
  numBytes += sLine_init(&sLine_dSd2evSE);
  numBytes += sBiquad_init(&sBiquad_s_8lEel2PL);
  numBytes += sLine_init(&sLine_jiGvYF38);
  numBytes += sLine_init(&sLine_qbklHF1L);
  numBytes += sLine_init(&sLine_Vp3laZPL);
  numBytes += sLine_init(&sLine_OgbO87I9);
  numBytes += sBiquad_init(&sBiquad_s_xnnPQN0C);
  numBytes += sLine_init(&sLine_S5cXmYtT);
  numBytes += sLine_init(&sLine_LyK7fv0B);
  numBytes += sLine_init(&sLine_qZ2Ecf5U);
  numBytes += sLine_init(&sLine_NntBvcpW);
  numBytes += sLine_init(&sLine_MrRX6NRp);
  numBytes += sBiquad_init(&sBiquad_s_LCIsYrVb);
  numBytes += sLine_init(&sLine_fljJ44sK);
  numBytes += sLine_init(&sLine_9wupr0VR);
  numBytes += sLine_init(&sLine_O5NGGsSd);
  numBytes += sLine_init(&sLine_2zQjHyvH);
  numBytes += sLine_init(&sLine_jRpmTe22);
  numBytes += sBiquad_init(&sBiquad_s_bhOdl786);
  numBytes += sLine_init(&sLine_GUQqJU4s);
  numBytes += sLine_init(&sLine_kMjfsphY);
  numBytes += sLine_init(&sLine_u40IXIkt);
  numBytes += sLine_init(&sLine_dYPLvLZs);
  numBytes += sBiquad_init(&sBiquad_s_G79NTCJf);
  numBytes += sLine_init(&sLine_Ki70oiwL);
  numBytes += sLine_init(&sLine_32xyaus1);
  numBytes += sLine_init(&sLine_ypmsRwLx);
  numBytes += sLine_init(&sLine_DbB5wF6s);
  numBytes += sLine_init(&sLine_Mujp5oLE);
  numBytes += sBiquad_init(&sBiquad_s_3c92ljaG);
  numBytes += sLine_init(&sLine_SiHkTrto);
  numBytes += sTabread_init(&sTabread_OpcZ7DJ1, &hTable_8ivaAy2P, true);
  numBytes += sLine_init(&sLine_PJfgcWfp);
  numBytes += sLine_init(&sLine_vhIaCNiQ);
  numBytes += sTabread_init(&sTabread_xsaDvBh2, &hTable_ZZIezVNP, true);
  numBytes += sLine_init(&sLine_4eqeo5B2);
  numBytes += sRPole_init(&sRPole_MCfKTWy5);
  numBytes += sDel1_init(&sDel1_bvCgA808);
  numBytes += sTabwrite_init(&sTabwrite_kWtHoB3q, &hTable_8ivaAy2P);
  numBytes += sRPole_init(&sRPole_VtAMkNya);
  numBytes += sDel1_init(&sDel1_CgtU2iXy);
  numBytes += sTabwrite_init(&sTabwrite_w2pURm5T, &hTable_ZZIezVNP);
  numBytes += sLine_init(&sLine_9AMDrpsb);
  numBytes += sLine_init(&sLine_tYY3DqE4);
  numBytes += sRPole_init(&sRPole_b0No4I6s);
  numBytes += sEnv_init(&sEnv_mUEGhEzw, 1024, 512);
  numBytes += sRPole_init(&sRPole_NapJOkmE);
  numBytes += sLine_init(&sLine_rMRI8Z8T);
  numBytes += sLine_init(&sLine_89DJZMCn);
  numBytes += sRPole_init(&sRPole_NDokYEo6);
  numBytes += sEnv_init(&sEnv_OwubAB32, 1024, 512);
  numBytes += sRPole_init(&sRPole_IxniHDuY);
  numBytes += sLine_init(&sLine_FrEBcdQy);
  numBytes += sTabread_init(&sTabread_rGRrRGcl, &hTable_7JlqoA3H, true);
  numBytes += sLine_init(&sLine_VjRAC79J);
  numBytes += sLine_init(&sLine_WNHKtmXy);
  numBytes += sTabread_init(&sTabread_EascK7nt, &hTable_bLqgvycv, true);
  numBytes += sLine_init(&sLine_v4eVq6Rx);
  numBytes += sRPole_init(&sRPole_d0W1xKH5);
  numBytes += sDel1_init(&sDel1_cX4E83Hp);
  numBytes += sTabwrite_init(&sTabwrite_liT688eE, &hTable_7JlqoA3H);
  numBytes += sRPole_init(&sRPole_WlwlbXj3);
  numBytes += sDel1_init(&sDel1_0E4HlE3e);
  numBytes += sTabwrite_init(&sTabwrite_HK8kvjCy, &hTable_bLqgvycv);
  numBytes += sLine_init(&sLine_PamYQFoh);
  numBytes += sLine_init(&sLine_jEJ6ZPTA);
  numBytes += sRPole_init(&sRPole_md6EVbKO);
  numBytes += sEnv_init(&sEnv_xlSxpIAL, 1024, 512);
  numBytes += sRPole_init(&sRPole_c8ZNGOaC);
  numBytes += sLine_init(&sLine_mk0ijScY);
  numBytes += sLine_init(&sLine_9EKY0QTN);
  numBytes += sRPole_init(&sRPole_Jn1Lfk61);
  numBytes += sEnv_init(&sEnv_wprhuXSZ, 1024, 512);
  numBytes += sRPole_init(&sRPole_E6n9NFiY);
  numBytes += sLine_init(&sLine_D8o1IQ9a);
  numBytes += sTabread_init(&sTabread_4yWhuYWi, &hTable_9oOiDax1, true);
  numBytes += sLine_init(&sLine_9gNqvxe8);
  numBytes += sLine_init(&sLine_zcdZoue6);
  numBytes += sTabread_init(&sTabread_TUNlizre, &hTable_8gImk5Wj, true);
  numBytes += sLine_init(&sLine_Z9mAmBX2);
  numBytes += sRPole_init(&sRPole_iMGA2AeB);
  numBytes += sDel1_init(&sDel1_mxQomP5v);
  numBytes += sTabwrite_init(&sTabwrite_I1NZKkvd, &hTable_9oOiDax1);
  numBytes += sRPole_init(&sRPole_LDUWhiTk);
  numBytes += sDel1_init(&sDel1_Yw98pb13);
  numBytes += sTabwrite_init(&sTabwrite_lezgKYhk, &hTable_8gImk5Wj);
  numBytes += sLine_init(&sLine_hePoyE3C);
  numBytes += sLine_init(&sLine_CQP4Afrq);
  numBytes += sRPole_init(&sRPole_1Ko7zf8N);
  numBytes += sEnv_init(&sEnv_sP9ygMXG, 1024, 512);
  numBytes += sRPole_init(&sRPole_qW5LtS1t);
  numBytes += sLine_init(&sLine_2DiqvxBr);
  numBytes += sLine_init(&sLine_TrYhwPa5);
  numBytes += sRPole_init(&sRPole_ev5v9nQC);
  numBytes += sEnv_init(&sEnv_5JrByhW4, 1024, 512);
  numBytes += sRPole_init(&sRPole_4GQLR2KN);
  numBytes += cVar_init_f(&cVar_zyAeuppi, 0.0f);
  numBytes += cVar_init_f(&cVar_h8oJMC1y, 0.0f);
  numBytes += cVar_init_f(&cVar_fnhtHAQA, 0.0f);
  numBytes += cVar_init_f(&cVar_tnr1Ubcv, 0.0f);
  numBytes += cSlice_init(&cSlice_lerQMlZB, 1, -1);
  numBytes += cVar_init_f(&cVar_RtKyE3Sq, 1337.0f);
  numBytes += cVar_init_f(&cVar_8T1F2TDL, 0.0f);
  numBytes += cIf_init(&cIf_Z9UmfPZz, false);
  numBytes += cIf_init(&cIf_QaWIbX2B, false);
  numBytes += cBinop_init(&cBinop_t8PH7ctD, 0.0f); // __pow
  numBytes += cIf_init(&cIf_jmy2shed, false);
  numBytes += cBinop_init(&cBinop_xgE8p9s2, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_pI1zp9gB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Bh6QkMnu, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_05sfXSSr, 0.0f);
  numBytes += cIf_init(&cIf_0vVQuvMY, false);
  numBytes += cIf_init(&cIf_ANPDSz8a, false);
  numBytes += cBinop_init(&cBinop_rWshSlZZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_tzDkbYmR, false);
  numBytes += cBinop_init(&cBinop_6fS6h8h6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ifllYoPP, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7ogFPFXr, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_c67VUYzo, 0.0f);
  numBytes += cIf_init(&cIf_bV8o011U, false);
  numBytes += cIf_init(&cIf_iNEPXZwU, false);
  numBytes += cBinop_init(&cBinop_74hA8zgO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_jdBOYpY5, false);
  numBytes += cBinop_init(&cBinop_G0XoR5sE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1Ynrt8OB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VSvrEp5t, -15.0f); // __eq
  numBytes += cIf_init(&cIf_2GJsVb7a, false);
  numBytes += cSlice_init(&cSlice_CIFwvD2E, 1, -1);
  numBytes += cVar_init_f(&cVar_3uMEvcL2, 0.0f);
  numBytes += cSlice_init(&cSlice_CGWjwPWQ, 1, -1);
  numBytes += cVar_init_f(&cVar_kwAn47Zz, 0.0f);
  numBytes += cSlice_init(&cSlice_VTkUUXwm, 1, -1);
  numBytes += cVar_init_f(&cVar_v1kMfpVX, 0.0f);
  numBytes += cSlice_init(&cSlice_ONCCpwm2, 1, -1);
  numBytes += cVar_init_f(&cVar_Ou6tJvnX, 0.313f);
  numBytes += cBinop_init(&cBinop_ybIRGQTj, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_RSJVFaiv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_87rKFy9y, 0.0f);
  numBytes += cVar_init_f(&cVar_fwVJ7RiH, 1337.0f);
  numBytes += cVar_init_f(&cVar_ilTJjsEH, 0.3f);
  numBytes += cBinop_init(&cBinop_PDsEvA2F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bQqddeVo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XiWij1yW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SSTCgsW1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k0mc1h08, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vgj6iEjg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HMHqBs08, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bMVuYtHQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Mplnsw25, 0.0f);
  numBytes += cVar_init_f(&cVar_8vis7q5m, 1337.0f);
  numBytes += cVar_init_f(&cVar_sJHWgBGP, 0.313f);
  numBytes += cBinop_init(&cBinop_ZDDszYZs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6uzXSxlC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GnUKLPPL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ojFiCNp8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ceo2qhoY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mAicPmIp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_p3HdoiYr, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DAuGDhDt, 0.0f);
  numBytes += cVar_init_f(&cVar_XBgnaUgW, 1037.0f);
  numBytes += cVar_init_f(&cVar_M5WnryKv, 0.4f);
  numBytes += cBinop_init(&cBinop_0PVgaYES, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IZJoxnGf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E7Zt0QUM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Uz3YXbOS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YT36BV6i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c49dA7dM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5UJgTd56, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_85VSfsXc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_np3EeWEt, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_oP74k9sU, 1, -1);
  numBytes += cVar_init_f(&cVar_WFLJSEIN, 1337.0f);
  numBytes += cVar_init_f(&cVar_rHyNkUmU, 0.0f);
  numBytes += cIf_init(&cIf_JQyh39N7, false);
  numBytes += cIf_init(&cIf_qiLaxl3I, false);
  numBytes += cBinop_init(&cBinop_8gN0CPfz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_VMOzQYwE, false);
  numBytes += cBinop_init(&cBinop_P3IqYIx1, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_IAxKcd5R, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_alRB4ktb, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_YYNGggqP, 0.0f);
  numBytes += cIf_init(&cIf_CTkFI44g, false);
  numBytes += cIf_init(&cIf_E4Li0gNV, false);
  numBytes += cBinop_init(&cBinop_XWHePzoq, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TmRcGCWh, false);
  numBytes += cBinop_init(&cBinop_ULt44w2G, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Bi0G9t0O, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_QdZOtKKI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_FBbQ6xj4, 0.0f);
  numBytes += cIf_init(&cIf_E90Y7j09, false);
  numBytes += cIf_init(&cIf_KSsGrN5d, false);
  numBytes += cBinop_init(&cBinop_hMYS4oz1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_zyf7ZDxe, false);
  numBytes += cBinop_init(&cBinop_DZ5uQY0n, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_RrMIMpqd, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_KfjiLK60, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Oi05mFKc, false);
  numBytes += cSlice_init(&cSlice_g5zVOlOI, 1, -1);
  numBytes += cVar_init_f(&cVar_Tp6FzV66, 0.0f);
  numBytes += cSlice_init(&cSlice_a2vMbKVs, 1, -1);
  numBytes += cVar_init_f(&cVar_rByvce28, 0.0f);
  numBytes += cSlice_init(&cSlice_kDI6MoNy, 1, -1);
  numBytes += cVar_init_f(&cVar_48q4yCNm, 0.0f);
  numBytes += cSlice_init(&cSlice_UzHNKtDl, 1, -1);
  numBytes += cVar_init_f(&cVar_AUNQW6dK, 0.313f);
  numBytes += cBinop_init(&cBinop_d1h7CmfT, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Xt5KvYbi, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_16FhDCaA, 0.0f);
  numBytes += cVar_init_f(&cVar_h1ohX5rw, 1337.0f);
  numBytes += cVar_init_f(&cVar_HIrriiED, 0.3f);
  numBytes += cBinop_init(&cBinop_hC8KzAfh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jw4ovqyo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_shrqvlij, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZvFbYBFm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iNzNowOH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Rw2HRWEP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JlFIoUTR, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_SgqucTaq, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_IuvJNLgO, 0.0f);
  numBytes += cVar_init_f(&cVar_dsntRGu8, 1337.0f);
  numBytes += cVar_init_f(&cVar_3V0LZl4N, 0.313f);
  numBytes += cBinop_init(&cBinop_JPgmiaYO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XOenZNm5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eo0vi1TF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GQnhUI6K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FEYLjTZa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1SQeXIPX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JPMHCuEz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_LuIWSKvZ, 0.0f);
  numBytes += cVar_init_f(&cVar_P0w80moO, 1037.0f);
  numBytes += cVar_init_f(&cVar_Wy6gNuZs, 0.4f);
  numBytes += cBinop_init(&cBinop_JErNPv7o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fVh2ys2S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7meioSWQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JAECJUXc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_56BLMODV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z8pWAe3q, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_hpcPsqTt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aDaQtmY7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cSyiPhTP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EQ3CZFqb, 5705.6f);
  numBytes += cVar_init_f(&cVar_8PJWEVa1, 313.3f);
  numBytes += cBinop_init(&cBinop_KPXAEZ9R, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_urGpZ7CD, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_cmi2ZzzV, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_sWQ1u0dg, 0.0f);
  numBytes += cVar_init_f(&cVar_2BJPvc7U, 0.0f);
  numBytes += cVar_init_f(&cVar_EVMHVwHC, 0.0f);
  numBytes += cVar_init_f(&cVar_6ZDjpTJT, 0.0f);
  numBytes += cVar_init_f(&cVar_N4tih93S, 0.0f);
  numBytes += cVar_init_f(&cVar_OHqurMx3, 0.0f);
  numBytes += cVar_init_f(&cVar_oLCD6zst, 0.0f);
  numBytes += cVar_init_f(&cVar_NhsUxSOv, 0.0f);
  numBytes += cVar_init_f(&cVar_07hesC6E, 0.0f);
  numBytes += cVar_init_f(&cVar_hHB05rRo, 0.0f);
  numBytes += cVar_init_f(&cVar_vDByRBCZ, 0.0f);
  numBytes += cVar_init_f(&cVar_yaZBfMoA, 0.0f);
  numBytes += cSlice_init(&cSlice_L30b8PJo, 1, -1);
  numBytes += cVar_init_f(&cVar_BBRviKV3, 0.5f);
  numBytes += cSlice_init(&cSlice_FR9DPd7D, 1, -1);
  numBytes += cVar_init_f(&cVar_CtHHBQmV, 0.2f);
  numBytes += cSlice_init(&cSlice_hq60Oppi, 1, -1);
  numBytes += cVar_init_f(&cVar_7FKMgrML, 500.0f);
  numBytes += sVarf_init(&sVarf_vbAXegNQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_tG8KpjXW, 600.0f);
  numBytes += cBinop_init(&cBinop_Tb7EFxgH, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_pSwUZzbP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f6dpVIu2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MnglVKN1, 600.0f);
  numBytes += cBinop_init(&cBinop_40GdEcMR, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_lEnoaVt5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xVGmRWBA, 4000.0f);
  numBytes += cBinop_init(&cBinop_3QlUkMEs, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_lO4qK856, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TyGI0rbR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_neS0EHoA, 4000.0f);
  numBytes += cBinop_init(&cBinop_Hi3vO1eI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_QF7Oh31e, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Noj6rC6D, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_REgfhzIh, false);
  numBytes += cBinop_init(&cBinop_C5ZPcw3I, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_spGo2FR3, 20.0f);
  numBytes += cBinop_init(&cBinop_tBbHtJ4M, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qOtrtMXM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MaOUQvBj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kJHkpQmY, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_csopc5F2, false);
  numBytes += cBinop_init(&cBinop_DRhAdYAb, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_sqR7zGZQ, 20.0f);
  numBytes += cBinop_init(&cBinop_1rMMqHpu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pvv8SV8e, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UMA2RpvU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5j3oY51H, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_eeev5Knv, 1, -1);
  numBytes += cVar_init_f(&cVar_4V59JlPb, 0.25f);
  numBytes += cDelay_init(this, &cDelay_0lkUAxVV, 0.0f);
  numBytes += cDelay_init(this, &cDelay_WXY0gOEs, 0.0f);
  numBytes += hTable_init(&hTable_8ivaAy2P, 256);
  numBytes += cTabhead_init(&cTabhead_g9D7nTb0, &hTable_8ivaAy2P);
  numBytes += cVar_init_s(&cVar_xLJKtZYB, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_x1Qd8vB6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_vhyepmZH, 0.0f);
  numBytes += cBinop_init(&cBinop_LQSNRBRE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p6tPQp6N, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_yQBqQHHK, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_RiBqSsFd, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_EsfZTanh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_GueQQom3, 0.0f);
  numBytes += hTable_init(&hTable_ZZIezVNP, 256);
  numBytes += cTabhead_init(&cTabhead_uEvGtxQJ, &hTable_ZZIezVNP);
  numBytes += cVar_init_s(&cVar_IoOkxZy6, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_lE9LUlt0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NgeQ8eYf, 0.0f);
  numBytes += cBinop_init(&cBinop_EAGNSJ0h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QF0uedcH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_tSP9q0fD, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_0524Z04m, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_IB2p0NoO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2yQTmld7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J1JeJTku, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wO4aQyHW, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_b0wjchqk, 1, -1);
  numBytes += cVar_init_f(&cVar_DMHRrMQq, 0.5f);
  numBytes += cSlice_init(&cSlice_nnel99SE, 1, -1);
  numBytes += cVar_init_f(&cVar_mZHCjmU9, 0.2f);
  numBytes += cSlice_init(&cSlice_4nBsMKuA, 1, -1);
  numBytes += cVar_init_f(&cVar_KzPuhE96, 500.0f);
  numBytes += sVarf_init(&sVarf_w7yg3Ipd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uxgWOwXM, 600.0f);
  numBytes += cBinop_init(&cBinop_bRzI7dtG, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_y7gZVT4Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x9LMNPBy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VUL8sCaa, 600.0f);
  numBytes += cBinop_init(&cBinop_0JsyIVfQ, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_HVsgKAIh, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_aIYCJqQk, 4000.0f);
  numBytes += cBinop_init(&cBinop_QwBfURPE, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_yvs9kQZU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7CoGcZtZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YrgZFoYY, 4000.0f);
  numBytes += cBinop_init(&cBinop_10b1Tuhq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_xWwoqGyP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Bbwr9HIk, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_IcyW2LGM, false);
  numBytes += cBinop_init(&cBinop_EMuWUsj1, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_CgSVQmn9, 20.0f);
  numBytes += cBinop_init(&cBinop_KOTyq4Ui, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SF6GTxrf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jewdPNQr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kACHp35I, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_H8saInOc, false);
  numBytes += cBinop_init(&cBinop_VoRxOAgp, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_DezhKF6R, 20.0f);
  numBytes += cBinop_init(&cBinop_VZbDzX7g, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5lDLb9pD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4cj1tFUE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o77aR6p6, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_5tmIUaGf, 1, -1);
  numBytes += cVar_init_f(&cVar_XzNNo5RU, 0.25f);
  numBytes += cDelay_init(this, &cDelay_nVkDo0qT, 0.0f);
  numBytes += cDelay_init(this, &cDelay_l9o7r3ju, 0.0f);
  numBytes += hTable_init(&hTable_7JlqoA3H, 256);
  numBytes += cTabhead_init(&cTabhead_k7c2qPjO, &hTable_7JlqoA3H);
  numBytes += cVar_init_s(&cVar_pcqH1HmT, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_A7FpN7b5, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BFtm417b, 0.0f);
  numBytes += cBinop_init(&cBinop_D8VCG4sC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XCrrDLTO, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_2QyLrNPR, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Sa51FHhP, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_O4uiejDB, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xjFsEJIH, 0.0f);
  numBytes += hTable_init(&hTable_bLqgvycv, 256);
  numBytes += cTabhead_init(&cTabhead_4A8SDNXc, &hTable_bLqgvycv);
  numBytes += cVar_init_s(&cVar_cdd5NsBa, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_H6jyPt6B, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3aHdUF8P, 0.0f);
  numBytes += cBinop_init(&cBinop_Ugp6S1MG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7Zd8E4pQ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_7Hs0gTSN, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_kg7gr3E6, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_7b5x3Etu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IBRQwiuw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YpkR6roQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B01C8WzZ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_OmOATDNE, 1, -1);
  numBytes += cVar_init_f(&cVar_2CXvN2eC, 0.5f);
  numBytes += cSlice_init(&cSlice_V1gBiR2S, 1, -1);
  numBytes += cVar_init_f(&cVar_MHprr7mE, 0.2f);
  numBytes += cSlice_init(&cSlice_ER1QuOYL, 1, -1);
  numBytes += cVar_init_f(&cVar_GjAneATj, 500.0f);
  numBytes += sVarf_init(&sVarf_fS4nUlFd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_82AhKPIj, 600.0f);
  numBytes += cBinop_init(&cBinop_trHgM645, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Y4kAoy2n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GmJxjfg8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_O2M1j7XT, 600.0f);
  numBytes += cBinop_init(&cBinop_xAPIgLiL, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_aMDV5QhE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cJ1mKNky, 4000.0f);
  numBytes += cBinop_init(&cBinop_JqNM74DB, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_iYDU982g, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M5x0W8ZR, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JEv7cZTL, 4000.0f);
  numBytes += cBinop_init(&cBinop_PGnIXsGC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FMWm79cD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fpRf9nTM, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_mzcwXbub, false);
  numBytes += cBinop_init(&cBinop_1BJPWF1X, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_6shtn7IU, 20.0f);
  numBytes += cBinop_init(&cBinop_F35kgNJW, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Xd6Pj0ju, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8JSg4GyH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dFSQ4B9D, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_D8L2vKih, false);
  numBytes += cBinop_init(&cBinop_nqK3CUUR, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_A0XliZu3, 20.0f);
  numBytes += cBinop_init(&cBinop_ABmds010, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8NArlSep, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p7c9rDB8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sAYI7Glt, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_bhjBudMt, 1, -1);
  numBytes += cVar_init_f(&cVar_tXMnp2tc, 0.25f);
  numBytes += cDelay_init(this, &cDelay_pFNjuVqQ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y3WIKYSW, 0.0f);
  numBytes += hTable_init(&hTable_9oOiDax1, 256);
  numBytes += cTabhead_init(&cTabhead_tmhNnqU2, &hTable_9oOiDax1);
  numBytes += cVar_init_s(&cVar_17NCJ1Qe, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_HWgBRcQH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FHkkLIPw, 0.0f);
  numBytes += cBinop_init(&cBinop_ghd1wTsN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3pULWc1C, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ppztfoLc, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_GnGE3FGj, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_D9vJF4bA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_DaIdrnE8, 0.0f);
  numBytes += hTable_init(&hTable_8gImk5Wj, 256);
  numBytes += cTabhead_init(&cTabhead_hJbtUJxh, &hTable_8gImk5Wj);
  numBytes += cVar_init_s(&cVar_oyf3QO4Y, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_0nW09Gir, 0.0f);
  numBytes += cDelay_init(this, &cDelay_pkofargY, 0.0f);
  numBytes += cBinop_init(&cBinop_VewR3gJE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_imYjl6n4, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9yPXQO6B, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_fscvRkxN, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_y98UhnWA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ia81Ax2O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4KXcErRU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lq9Hohxa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0iOdc2E1, 1.0f);
  numBytes += cIf_init(&cIf_IPn2yIfd, false);
  numBytes += cIf_init(&cIf_iMrWqOsq, false);
  numBytes += cVar_init_f(&cVar_s4AwjXm8, 0.0f);
  numBytes += cVar_init_f(&cVar_R23fXq5o, 0.0f);
  numBytes += cVar_init_f(&cVar_SFttxh9i, 1.0f);
  numBytes += cIf_init(&cIf_09DjQoN6, false);
  numBytes += cIf_init(&cIf_PtL9VEmS, false);
  numBytes += cVar_init_f(&cVar_Cbbdjo1A, 0.0f);
  numBytes += cVar_init_f(&cVar_CowyJzkV, 0.0f);
  numBytes += cVar_init_f(&cVar_d7Leqv0V, 1.0f);
  numBytes += cIf_init(&cIf_nrvgTTcx, false);
  numBytes += cIf_init(&cIf_4h1IrHQd, false);
  numBytes += cVar_init_f(&cVar_6bm554UU, 0.0f);
  numBytes += cVar_init_f(&cVar_VPRQAEvi, 0.0f);
  numBytes += cVar_init_f(&cVar_z1M0czwq, 60000.0f);
  numBytes += cVar_init_f(&cVar_xTARVGZM, 500.0f);
  numBytes += cSlice_init(&cSlice_nmqJB38J, 1, -1);
  numBytes += cSlice_init(&cSlice_6fPuX4ug, 1, -1);
  numBytes += cVar_init_f(&cVar_wGV5d0fX, 0.0f);
  numBytes += cIf_init(&cIf_D5CDU2mp, false);
  numBytes += cBinop_init(&cBinop_1feUHurt, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_tcdhWlqF, 120.0f);
  numBytes += cBinop_init(&cBinop_cEy7lamz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_kEcG9gC9, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kMaiPoXH, 60000.0f);
  numBytes += cVar_init_f(&cVar_GCEMjEK3, 500.0f);
  numBytes += cSlice_init(&cSlice_aOP32ccM, 1, -1);
  numBytes += cSlice_init(&cSlice_na8xKPsm, 1, -1);
  numBytes += cVar_init_f(&cVar_HoTBaWYB, 0.0f);
  numBytes += cIf_init(&cIf_b27hPo8H, false);
  numBytes += cBinop_init(&cBinop_fk2MClbO, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_bamSgTOS, 120.0f);
  numBytes += cBinop_init(&cBinop_BPSBvHuu, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_YkGkAadO, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FNOxbhKG, 60000.0f);
  numBytes += cVar_init_f(&cVar_RuYHqKoc, 500.0f);
  numBytes += cSlice_init(&cSlice_5SDmrm5X, 1, -1);
  numBytes += cSlice_init(&cSlice_6bnTFrr2, 1, -1);
  numBytes += cVar_init_f(&cVar_SSCt4e1g, 0.0f);
  numBytes += cIf_init(&cIf_v7hPHK2T, false);
  numBytes += cBinop_init(&cBinop_ozzD3Q2W, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_V6TBUuQE, 120.0f);
  numBytes += cBinop_init(&cBinop_BULf5Hsz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_TZTUeKpU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2ONjKLir, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ei9pEYN8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l7xnBLoT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kV64asir, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SlezXjgT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mBzeYffg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2FAlNnCg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RaRqaGRw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c9CZFQua, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9p8oxtoI, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_mUEGhEzw);
  sEnv_free(&sEnv_OwubAB32);
  sEnv_free(&sEnv_xlSxpIAL);
  sEnv_free(&sEnv_wprhuXSZ);
  sEnv_free(&sEnv_sP9ygMXG);
  sEnv_free(&sEnv_5JrByhW4);
  hTable_free(&hTable_8ivaAy2P);
  hTable_free(&hTable_ZZIezVNP);
  hTable_free(&hTable_7JlqoA3H);
  hTable_free(&hTable_bLqgvycv);
  hTable_free(&hTable_9oOiDax1);
  hTable_free(&hTable_8gImk5Wj);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_8ivaAy2P; // del-1349-delayL
    case 0x19A00729: return &hTable_ZZIezVNP; // del-1349-delayR
    case 0x584C8281: return &hTable_7JlqoA3H; // del-1428-delayL
    case 0x54BF59F6: return &hTable_bLqgvycv; // del-1428-delayR
    case 0xBCE693A: return &hTable_9oOiDax1; // del-1507-delayL
    case 0x95A380B3: return &hTable_8gImk5Wj; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mJS271um_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vmMF6BXY_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_92SaExm6_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b1F0LfBn_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XI2d8j6C_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aIaky8y4_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DymIz6rj_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oGRup8gv_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Os7sK6sR_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yCivyehN_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BugdylM0_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7EMQTVfF_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L0rRhCSM_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1CxV2LuS_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w8whdEiX_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Jgh5RS5_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FdBOCn5Y_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_btsDG1tZ_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Zos71Fj_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kOw5lEs6_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Zx1gsONL_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SdcqfYb6_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nlb5PYEE_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WQrU5MVU_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e5dDX53L_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qC39zOB0_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FyfxgPdy_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WEWC6vLT_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wLu6Kumm_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LRo7Ipbv_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dQxoFvjd_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eczcJID0_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ooF0SNmQ_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YLJrSkUB_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UJUiOrll_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eSByEXND_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wVgKrjDe_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CnQbqLCm_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0ihn8ChK_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_105AVEkT_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8GOBq7RD_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1vqjxvL8_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6C7agtLx_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vmvdUYmF_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8fuAb2Sf_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jSiCIRGJ_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UuJIszpq_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_apcANYBb_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mdrdIGC2_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BfZxmlGj_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lShH9u6V_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_onbMeAjM_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Uyxy75y3_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HrM5fwGJ_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mPh1lRLI_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uoLKfGzj_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zR6v04j2_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mLMfzuBh_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_x13ud81Z_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gRxaeJAI_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uKCJR26i_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1NZrvZDg_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LppNwLpb_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dYEe7G67_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_zyAeuppi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xWcXd1um_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_h8oJMC1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dcZZCXlh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_fnhtHAQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_frk5YCaH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_tnr1Ubcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rBi7i4dL_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PMZx31QJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NrokZlJr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yFmycH87_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zXcmlk59_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lerQMlZB, 0, m, &cSlice_lerQMlZB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Qagh8hyR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_lerQMlZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8dB0kCC9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8dB0kCC9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_RtKyE3Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8dB0kCC9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8dB0kCC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e5dDX53L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8T1F2TDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UmZHCGw7_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Z9UmfPZz, 0, m, &cIf_Z9UmfPZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Z9UmfPZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aj6NhpwU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_QaWIbX2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4gLvSuQM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5htbbOPk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_2dnInHaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_t8PH7ctD, HV_BINOP_POW, 0, m, &cBinop_t8PH7ctD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t8PH7ctD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jmy2shed, 0, m, &cIf_jmy2shed_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oVUd2K23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_re5ICFTU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OQNLMFIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_SJ3zjEjT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RS8btLKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaWIbX2B, 0, m, &cIf_QaWIbX2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SJ3zjEjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaWIbX2B, 1, m, &cIf_QaWIbX2B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5htbbOPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_oVUd2K23_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4gLvSuQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_jmy2shed, 0, m, &cIf_jmy2shed_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_re5ICFTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t8PH7ctD, HV_BINOP_POW, 1, m, &cBinop_t8PH7ctD_sendMessage);
  cMsg_2dnInHaR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_jmy2shed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5UJgTd56, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_UmZHCGw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z9UmfPZz, 1, m, &cIf_Z9UmfPZz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aj6NhpwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pI1zp9gB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pI1zp9gB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bh6QkMnu, HV_BINOP_EQ, 1, m, &cBinop_Bh6QkMnu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Zh14uMtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xgE8p9s2, HV_BINOP_ADD, 0, m, &cBinop_xgE8p9s2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xgE8p9s2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OQNLMFIQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RS8btLKS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pI1zp9gB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jmy2shed, 1, m, &cIf_jmy2shed_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bh6QkMnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jAFiTaIy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_jAFiTaIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5UJgTd56, m);
}

void Heavy_WSTD_DL3Y::cCast_fYjD5gGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xgE8p9s2, HV_BINOP_ADD, 1, m, &cBinop_xgE8p9s2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pI1zp9gB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pI1zp9gB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bh6QkMnu, HV_BINOP_EQ, 0, m, &cBinop_Bh6QkMnu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Sdf1VcfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zh14uMtB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_gf89nSh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8T1F2TDL, 0, m, &cVar_8T1F2TDL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_05sfXSSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1xWDxzl2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0vVQuvMY, 0, m, &cIf_0vVQuvMY_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_0vVQuvMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_B1SRvs8E_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_ANPDSz8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QeZ7Fvtv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_fopNIefc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Sh1p947u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWshSlZZ, HV_BINOP_POW, 0, m, &cBinop_rWshSlZZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rWshSlZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tzDkbYmR, 0, m, &cIf_tzDkbYmR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uFLQpph7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9ws8EgFz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tb9QFhYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uhndQiJA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qlSzhZ8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ANPDSz8a, 0, m, &cIf_ANPDSz8a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uhndQiJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ANPDSz8a, 1, m, &cIf_ANPDSz8a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fopNIefc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uFLQpph7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QeZ7Fvtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tzDkbYmR, 0, m, &cIf_tzDkbYmR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ws8EgFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWshSlZZ, HV_BINOP_POW, 1, m, &cBinop_rWshSlZZ_sendMessage);
  cMsg_Sh1p947u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_tzDkbYmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nFTkYA4O_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hZpyW9pG_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_xoLUe976_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_1xWDxzl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0vVQuvMY, 1, m, &cIf_0vVQuvMY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B1SRvs8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ifllYoPP, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ifllYoPP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ogFPFXr, HV_BINOP_EQ, 1, m, &cBinop_7ogFPFXr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Jn2jU1qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6fS6h8h6, HV_BINOP_ADD, 0, m, &cBinop_6fS6h8h6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6fS6h8h6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tb9QFhYt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qlSzhZ8j_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ifllYoPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tzDkbYmR, 1, m, &cIf_tzDkbYmR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7ogFPFXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fzeW1IaN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_fzeW1IaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nFTkYA4O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hZpyW9pG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_xoLUe976_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C1ckdgUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jn2jU1qT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JKEOd0pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6fS6h8h6, HV_BINOP_ADD, 1, m, &cBinop_6fS6h8h6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ifllYoPP, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ifllYoPP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ogFPFXr, HV_BINOP_EQ, 0, m, &cBinop_7ogFPFXr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rSiLAiZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_05sfXSSr, 0, m, &cVar_05sfXSSr_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_c67VUYzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6nOKO1VJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_bV8o011U, 0, m, &cIf_bV8o011U_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_bV8o011U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HTRL07T0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_iNEPXZwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_GjotRgvd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JlFKmwNe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Vpp36GCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_74hA8zgO, HV_BINOP_POW, 0, m, &cBinop_74hA8zgO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_74hA8zgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jdBOYpY5, 0, m, &cIf_jdBOYpY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7X8S86z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xh3ZBAT3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ohInZTq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_a3Y0ltMs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U2dAANpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iNEPXZwU, 0, m, &cIf_iNEPXZwU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a3Y0ltMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iNEPXZwU, 1, m, &cIf_iNEPXZwU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JlFKmwNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_7X8S86z6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GjotRgvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_jdBOYpY5, 0, m, &cIf_jdBOYpY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xh3ZBAT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_74hA8zgO, HV_BINOP_POW, 1, m, &cBinop_74hA8zgO_sendMessage);
  cMsg_Vpp36GCu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_jdBOYpY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_np3EeWEt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_6nOKO1VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bV8o011U, 1, m, &cIf_bV8o011U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HTRL07T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Ynrt8OB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1Ynrt8OB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VSvrEp5t, HV_BINOP_EQ, 1, m, &cBinop_VSvrEp5t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QJoDcFvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_G0XoR5sE, HV_BINOP_ADD, 0, m, &cBinop_G0XoR5sE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G0XoR5sE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ohInZTq7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U2dAANpY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1Ynrt8OB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jdBOYpY5, 1, m, &cIf_jdBOYpY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VSvrEp5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KOsmGlPr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KOsmGlPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_np3EeWEt, m);
}

void Heavy_WSTD_DL3Y::cCast_QlW9VlFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c67VUYzo, 0, m, &cVar_c67VUYzo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kszPgf0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QJoDcFvU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nTfbjxID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G0XoR5sE, HV_BINOP_ADD, 1, m, &cBinop_G0XoR5sE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Ynrt8OB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1Ynrt8OB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VSvrEp5t, HV_BINOP_EQ, 0, m, &cBinop_VSvrEp5t_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2GJsVb7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_85VSfsXc, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_b7Wboe3S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CIFwvD2E, 0, m, &cSlice_CIFwvD2E_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PeK4quEP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CIFwvD2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yBrz5ssF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yBrz5ssF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_3uMEvcL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yBrz5ssF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_yBrz5ssF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nlb5PYEE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PeK4quEP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CGWjwPWQ, 0, m, &cSlice_CGWjwPWQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zXcmlk59_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CGWjwPWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YSzJqHmE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YSzJqHmE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kwAn47Zz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YSzJqHmE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YSzJqHmE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FyfxgPdy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Qagh8hyR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VTkUUXwm, 0, m, &cSlice_VTkUUXwm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PA1TOr5M_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_VTkUUXwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QkwyqWf6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QkwyqWf6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_v1kMfpVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QkwyqWf6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QkwyqWf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WQrU5MVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_PA1TOr5M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ONCCpwm2, 0, m, &cSlice_ONCCpwm2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ONCCpwm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qr5eOWa8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qr5eOWa8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Ou6tJvnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qr5eOWa8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qr5eOWa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qC39zOB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_smUJr82H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Nr778c4c, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_0Vpdmsj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bqJlyGNs, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gG3EPCi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5O11rrrH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Fk8ZDftO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KKhe5vKv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CGvQOzgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dSd2evSE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UmIgD4sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_a2KK8Ivs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_a2KK8Ivs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybIRGQTj, HV_BINOP_DIVIDE, 1, m, &cBinop_ybIRGQTj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0V6uEyPA_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_LGD2cfhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_nk5Yg8za_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7t8ZMEQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_LGD2cfhm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nk5Yg8za_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ybIRGQTj, HV_BINOP_DIVIDE, 0, m, &cBinop_ybIRGQTj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0V6uEyPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7t8ZMEQu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ybIRGQTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RSJVFaiv, HV_BINOP_MULTIPLY, 1, m, &cBinop_RSJVFaiv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RSJVFaiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9sppFxn8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZBYXP1bq_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_1DgRcECy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OA6gBbqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_UH5JI6Zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xN7tjkkO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XtObuzyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_crtT27w0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_crtT27w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RSJVFaiv, HV_BINOP_MULTIPLY, 0, m, &cBinop_RSJVFaiv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R5WPhRZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RnUbq6ig_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RnUbq6ig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vxk8lx1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XASHvAIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_87rKFy9y, 1, m, &cVar_87rKFy9y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_87rKFy9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4i6EadLX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZFPMxOXi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bQqddeVo, HV_BINOP_MULTIPLY, 1, m, &cBinop_bQqddeVo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lsxf6UKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZFPMxOXi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_efYCcPpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4nMPAI5r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4nMPAI5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiWij1yW, HV_BINOP_MULTIPLY, 1, m, &cBinop_XiWij1yW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Be0V9eWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SSTCgsW1, HV_BINOP_MULTIPLY, 1, m, &cBinop_SSTCgsW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g4jLuJO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Be0V9eWR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7t5IgWEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0mc1h08, HV_BINOP_MULTIPLY, 1, m, &cBinop_k0mc1h08_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s31DheaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mt2HkS3i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mt2HkS3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vgj6iEjg, HV_BINOP_MULTIPLY, 1, m, &cBinop_vgj6iEjg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fwVJ7RiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PTBYxilF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XtObuzyO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uMCbzLm3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ilTJjsEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_R5WPhRZ1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9sppFxn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_1DgRcECy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZBYXP1bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_UH5JI6Zb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_OA6gBbqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LRo7Ipbv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xN7tjkkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wLu6Kumm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KBjvxvee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WEWC6vLT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Vxk8lx1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qbcM9F9m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qbcM9F9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PDsEvA2F, HV_BINOP_MULTIPLY, 1, m, &cBinop_PDsEvA2F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PDsEvA2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_L2KLuXzV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L2KLuXzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KBjvxvee_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_4i6EadLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HYVj8hEJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HYVj8hEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K2O7oWEQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sMD1s9KJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1o3lTS1l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_diufXRzw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8th81cGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lu126IRC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bQqddeVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_smUJr82H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XiWij1yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Vpdmsj6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SSTCgsW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gG3EPCi5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_k0mc1h08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fk8ZDftO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vgj6iEjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CGvQOzgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LPbtTy6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fwVJ7RiH, 0, m, &cVar_fwVJ7RiH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_b0nUvJsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ilTJjsEH, 1, m, &cVar_ilTJjsEH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K2O7oWEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_8th81cGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XiWij1yW, HV_BINOP_MULTIPLY, 0, m, &cBinop_XiWij1yW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lu126IRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bQqddeVo, HV_BINOP_MULTIPLY, 0, m, &cBinop_bQqddeVo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_diufXRzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SSTCgsW1, HV_BINOP_MULTIPLY, 0, m, &cBinop_SSTCgsW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1o3lTS1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0mc1h08, HV_BINOP_MULTIPLY, 0, m, &cBinop_k0mc1h08_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sMD1s9KJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vgj6iEjg, HV_BINOP_MULTIPLY, 0, m, &cBinop_vgj6iEjg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uMCbzLm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_87rKFy9y, 0, m, &cVar_87rKFy9y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PTBYxilF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ilTJjsEH, 0, m, &cVar_ilTJjsEH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XHU9iczE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jiGvYF38, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7FiRFoDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qbklHF1L, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QK34salM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vp3laZPL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_i0CGU0OW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OgbO87I9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Wye0PkbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eNucOIf5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_eNucOIf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HMHqBs08, HV_BINOP_DIVIDE, 1, m, &cBinop_HMHqBs08_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1MLOXRAP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_FWSZchNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dqZfgVWO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_za8b3fpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FWSZchNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dqZfgVWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HMHqBs08, HV_BINOP_DIVIDE, 0, m, &cBinop_HMHqBs08_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1MLOXRAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_za8b3fpg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HMHqBs08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMVuYtHQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_bMVuYtHQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bMVuYtHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mDvGk9ck_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k6GGT9w3_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_NLZEW03x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SRcxvqXT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_DAmKKxUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dvXmLi9X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rp0qO8gH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_vDsrZRli_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vDsrZRli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMVuYtHQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_bMVuYtHQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3HN9qTPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kq9RTF6H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kq9RTF6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y0ZD70iI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Fd7m82Ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnUKLPPL, HV_BINOP_MULTIPLY, 1, m, &cBinop_GnUKLPPL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lxRkkHQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mplnsw25, 1, m, &cVar_Mplnsw25_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iaRgc0cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ojFiCNp8, HV_BINOP_MULTIPLY, 1, m, &cBinop_ojFiCNp8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KpOfNB5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vE7ArJLG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vE7ArJLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ceo2qhoY, HV_BINOP_MULTIPLY, 1, m, &cBinop_ceo2qhoY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Mplnsw25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0SIWOXjR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8vis7q5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rfrv8LpN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rp0qO8gH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uSxPFpHu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_sJHWgBGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3HN9qTPj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mDvGk9ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NLZEW03x_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_k6GGT9w3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_DAmKKxUm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_SRcxvqXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ooF0SNmQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_dvXmLi9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eczcJID0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_RbttloA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dQxoFvjd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Y0ZD70iI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_djCMPshS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_djCMPshS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZDDszYZs, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZDDszYZs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZDDszYZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_E2DowZXP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E2DowZXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RbttloA5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0SIWOXjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gJotw10L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gJotw10L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CHPzZm5P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G3hLtVwX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fcm3mUki_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kpFEe6ZX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6uzXSxlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XHU9iczE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GnUKLPPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7FiRFoDd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ojFiCNp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QK34salM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ceo2qhoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i0CGU0OW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_OZkBGwVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8vis7q5m, 0, m, &cVar_8vis7q5m_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GQF06SUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sJHWgBGP, 1, m, &cVar_sJHWgBGP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Rfrv8LpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sJHWgBGP, 0, m, &cVar_sJHWgBGP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uSxPFpHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mplnsw25, 0, m, &cVar_Mplnsw25_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fcm3mUki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnUKLPPL, HV_BINOP_MULTIPLY, 0, m, &cBinop_GnUKLPPL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kpFEe6ZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6uzXSxlC, HV_BINOP_MULTIPLY, 0, m, &cBinop_6uzXSxlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_G3hLtVwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ojFiCNp8, HV_BINOP_MULTIPLY, 0, m, &cBinop_ojFiCNp8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CHPzZm5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ceo2qhoY, HV_BINOP_MULTIPLY, 0, m, &cBinop_ceo2qhoY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kH2veuUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S5cXmYtT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PtdikpkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LyK7fv0B, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ndl5AF7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qZ2Ecf5U, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_c6p83c2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NntBvcpW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FtxpAf56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MrRX6NRp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wqGRlket_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L1cQYali_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_L1cQYali_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mAicPmIp, HV_BINOP_DIVIDE, 1, m, &cBinop_mAicPmIp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8y9ldKM1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_PdhbfAP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oYEfp0Pu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7XR6DdqB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_PdhbfAP5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oYEfp0Pu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mAicPmIp, HV_BINOP_DIVIDE, 0, m, &cBinop_mAicPmIp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8y9ldKM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7XR6DdqB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mAicPmIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p3HdoiYr, HV_BINOP_MULTIPLY, 1, m, &cBinop_p3HdoiYr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p3HdoiYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9WD39aEU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3IYVk3br_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_lEz6GSSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9RB7rI6T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_JE3cZXZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JCGdoxCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_z2vjUS28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Zbjhk4Hp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zbjhk4Hp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p3HdoiYr, HV_BINOP_MULTIPLY, 0, m, &cBinop_p3HdoiYr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_al8i25Eo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zuMhVYQe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zuMhVYQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hb0p0lnE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_W0d0KMRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZJoxnGf, HV_BINOP_MULTIPLY, 1, m, &cBinop_IZJoxnGf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gSXBTzlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KmDCIu0U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KmDCIu0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_W0d0KMRH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UqwqGbDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_j8NBEFpu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_j8NBEFpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E7Zt0QUM, HV_BINOP_MULTIPLY, 1, m, &cBinop_E7Zt0QUM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xjF4FPLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uz3YXbOS, HV_BINOP_MULTIPLY, 1, m, &cBinop_Uz3YXbOS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Gtr87bYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mLMnpzs7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mLMnpzs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xjF4FPLQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gycJ3cXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DAuGDhDt, 1, m, &cVar_DAuGDhDt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lunIDHvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YT36BV6i, HV_BINOP_MULTIPLY, 1, m, &cBinop_YT36BV6i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pkfcohZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kRPyIWZu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kRPyIWZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c49dA7dM, HV_BINOP_MULTIPLY, 1, m, &cBinop_c49dA7dM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DAuGDhDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vNDsDyNf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XBgnaUgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CAHPEhm0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_z2vjUS28_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6qCseAsn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_M5WnryKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_al8i25Eo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3IYVk3br_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JE3cZXZA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9WD39aEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_lEz6GSSn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_9RB7rI6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eSByEXND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_JCGdoxCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UJUiOrll_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_FXQcmmBD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YLJrSkUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Hb0p0lnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_o4vb4L9R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o4vb4L9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0PVgaYES, HV_BINOP_MULTIPLY, 1, m, &cBinop_0PVgaYES_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0PVgaYES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MbehPRbY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MbehPRbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FXQcmmBD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vNDsDyNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UNLKxIV2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UNLKxIV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FmE2rbKC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i0OBtcjH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lXWe2i8l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PSfrAuQk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ho2cxzcZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f0REc72G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IZJoxnGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kH2veuUH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_E7Zt0QUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PtdikpkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Uz3YXbOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ndl5AF7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YT36BV6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c6p83c2a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_c49dA7dM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FtxpAf56_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JjLaymDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XBgnaUgW, 0, m, &cVar_XBgnaUgW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_D4sTHhzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M5WnryKv, 1, m, &cVar_M5WnryKv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FmE2rbKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_lXWe2i8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YT36BV6i, HV_BINOP_MULTIPLY, 0, m, &cBinop_YT36BV6i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PSfrAuQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Uz3YXbOS, HV_BINOP_MULTIPLY, 0, m, &cBinop_Uz3YXbOS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_i0OBtcjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c49dA7dM, HV_BINOP_MULTIPLY, 0, m, &cBinop_c49dA7dM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ho2cxzcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E7Zt0QUM, HV_BINOP_MULTIPLY, 0, m, &cBinop_E7Zt0QUM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f0REc72G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IZJoxnGf, HV_BINOP_MULTIPLY, 0, m, &cBinop_IZJoxnGf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CAHPEhm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M5WnryKv, 0, m, &cVar_M5WnryKv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6qCseAsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DAuGDhDt, 0, m, &cVar_DAuGDhDt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nFTkYA4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2GJsVb7a, 1, m, &cIf_2GJsVb7a_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IodJNO0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_85VSfsXc, m);
}

void Heavy_WSTD_DL3Y::cBinop_hZpyW9pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IodJNO0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xoLUe976_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2GJsVb7a, 0, m, &cIf_2GJsVb7a_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4DmQoWwc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oP74k9sU, 0, m, &cSlice_oP74k9sU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ETWrsURi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_oP74k9sU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fkJWiL5Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fkJWiL5Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_WFLJSEIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fkJWiL5Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fkJWiL5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0ihn8ChK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_rHyNkUmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_S6pj6XgP_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_JQyh39N7, 0, m, &cIf_JQyh39N7_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JQyh39N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZmueO5er_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_qiLaxl3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Uv3nSjU9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_SMz9KLc5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_98w9nryP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8gN0CPfz, HV_BINOP_POW, 0, m, &cBinop_8gN0CPfz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8gN0CPfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMOzQYwE, 0, m, &cIf_VMOzQYwE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0fcboBA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_7uOENejs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Rvm149Jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_keN655rd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JKVDLeV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qiLaxl3I, 0, m, &cIf_qiLaxl3I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_keN655rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qiLaxl3I, 1, m, &cIf_qiLaxl3I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SMz9KLc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0fcboBA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Uv3nSjU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_VMOzQYwE, 0, m, &cIf_VMOzQYwE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7uOENejs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8gN0CPfz, HV_BINOP_POW, 1, m, &cBinop_8gN0CPfz_sendMessage);
  cMsg_98w9nryP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_VMOzQYwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_hpcPsqTt, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_S6pj6XgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JQyh39N7, 1, m, &cIf_JQyh39N7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZmueO5er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IAxKcd5R, HV_BINOP_GREATER_THAN, 1, m, &cBinop_IAxKcd5R_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_alRB4ktb, HV_BINOP_EQ, 1, m, &cBinop_alRB4ktb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dYLSKdZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P3IqYIx1, HV_BINOP_ADD, 0, m, &cBinop_P3IqYIx1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P3IqYIx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rvm149Jm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JKVDLeV3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IAxKcd5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VMOzQYwE, 1, m, &cIf_VMOzQYwE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_alRB4ktb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BOEbiUbG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_BOEbiUbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hpcPsqTt, m);
}

void Heavy_WSTD_DL3Y::cCast_eEWR5aec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rHyNkUmU, 0, m, &cVar_rHyNkUmU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BGgdiRIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P3IqYIx1, HV_BINOP_ADD, 1, m, &cBinop_P3IqYIx1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IAxKcd5R, HV_BINOP_GREATER_THAN, 0, m, &cBinop_IAxKcd5R_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_alRB4ktb, HV_BINOP_EQ, 0, m, &cBinop_alRB4ktb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nIYwy2eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dYLSKdZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YYNGggqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vfQEszkc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_CTkFI44g, 0, m, &cIf_CTkFI44g_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_CTkFI44g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ghPt8e0R_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_E4Li0gNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mVtkQjGc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mLwyg6TA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Ufoa6d5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XWHePzoq, HV_BINOP_POW, 0, m, &cBinop_XWHePzoq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XWHePzoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TmRcGCWh, 0, m, &cIf_TmRcGCWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZqRi8Ceb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0yYOA5vh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HBOAX1kh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_P9nWyh1Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_56BBEhxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E4Li0gNV, 0, m, &cIf_E4Li0gNV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P9nWyh1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E4Li0gNV, 1, m, &cIf_E4Li0gNV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mLwyg6TA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZqRi8Ceb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mVtkQjGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TmRcGCWh, 0, m, &cIf_TmRcGCWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0yYOA5vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XWHePzoq, HV_BINOP_POW, 1, m, &cBinop_XWHePzoq_sendMessage);
  cMsg_Ufoa6d5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_TmRcGCWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_S7J4ZTRV_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hlN05cl4_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_pTIEbQKK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_vfQEszkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CTkFI44g, 1, m, &cIf_CTkFI44g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ghPt8e0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bi0G9t0O, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Bi0G9t0O_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QdZOtKKI, HV_BINOP_EQ, 1, m, &cBinop_QdZOtKKI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8QScEiPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ULt44w2G, HV_BINOP_ADD, 0, m, &cBinop_ULt44w2G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ULt44w2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HBOAX1kh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_56BBEhxk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bi0G9t0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TmRcGCWh, 1, m, &cIf_TmRcGCWh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QdZOtKKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bOHyXhv5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bOHyXhv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_S7J4ZTRV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hlN05cl4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_pTIEbQKK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ykDlqg5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ULt44w2G, HV_BINOP_ADD, 1, m, &cBinop_ULt44w2G_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bi0G9t0O, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Bi0G9t0O_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QdZOtKKI, HV_BINOP_EQ, 0, m, &cBinop_QdZOtKKI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lYHPigvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YYNGggqP, 0, m, &cVar_YYNGggqP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_krXjm1bT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8QScEiPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FBbQ6xj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i1BEG4rW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_E90Y7j09, 0, m, &cIf_E90Y7j09_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_E90Y7j09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3Sfk8Mi3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_KSsGrN5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MpCl4rc3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_4nd87lL0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_x3iGugqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hMYS4oz1, HV_BINOP_POW, 0, m, &cBinop_hMYS4oz1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hMYS4oz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zyf7ZDxe, 0, m, &cIf_zyf7ZDxe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gttblUlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Z6xmRhWP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_N24i2hr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KSsGrN5d, 0, m, &cIf_KSsGrN5d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kFfxZxof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YSjw54wR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YSjw54wR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KSsGrN5d, 1, m, &cIf_KSsGrN5d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4nd87lL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gttblUlJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MpCl4rc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_zyf7ZDxe, 0, m, &cIf_zyf7ZDxe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z6xmRhWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hMYS4oz1, HV_BINOP_POW, 1, m, &cBinop_hMYS4oz1_sendMessage);
  cMsg_x3iGugqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_zyf7ZDxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_cSyiPhTP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_i1BEG4rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E90Y7j09, 1, m, &cIf_E90Y7j09_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3Sfk8Mi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RrMIMpqd, HV_BINOP_GREATER_THAN, 1, m, &cBinop_RrMIMpqd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KfjiLK60, HV_BINOP_EQ, 1, m, &cBinop_KfjiLK60_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Yyb8MtLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZ5uQY0n, HV_BINOP_ADD, 0, m, &cBinop_DZ5uQY0n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DZ5uQY0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kFfxZxof_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N24i2hr3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RrMIMpqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zyf7ZDxe, 1, m, &cIf_zyf7ZDxe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KfjiLK60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RRTNipzD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_RRTNipzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cSyiPhTP, m);
}

void Heavy_WSTD_DL3Y::cCast_0O2Yewpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FBbQ6xj4, 0, m, &cVar_FBbQ6xj4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GgqdP2xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yyb8MtLa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_y7oDZHIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZ5uQY0n, HV_BINOP_ADD, 1, m, &cBinop_DZ5uQY0n_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RrMIMpqd, HV_BINOP_GREATER_THAN, 0, m, &cBinop_RrMIMpqd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KfjiLK60, HV_BINOP_EQ, 0, m, &cBinop_KfjiLK60_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Oi05mFKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_aDaQtmY7, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_PAI4VYSO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g5zVOlOI, 0, m, &cSlice_g5zVOlOI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_I4itvaqA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_g5zVOlOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3zWmhONm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3zWmhONm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Tp6FzV66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3zWmhONm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_3zWmhONm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wVgKrjDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_I4itvaqA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a2vMbKVs, 0, m, &cSlice_a2vMbKVs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4DmQoWwc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_a2vMbKVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KZGKBYtS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KZGKBYtS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_rByvce28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KZGKBYtS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KZGKBYtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8GOBq7RD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ETWrsURi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kDI6MoNy, 0, m, &cSlice_kDI6MoNy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GA2p5MtW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_kDI6MoNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_A3oCCzJP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_A3oCCzJP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_48q4yCNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A3oCCzJP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_A3oCCzJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CnQbqLCm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_GA2p5MtW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UzHNKtDl, 0, m, &cSlice_UzHNKtDl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UzHNKtDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UrUs26f7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UrUs26f7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_AUNQW6dK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UrUs26f7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_UrUs26f7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_105AVEkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_pe9Qjjl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fljJ44sK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_g1WWA1WR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9wupr0VR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TJ381csy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O5NGGsSd, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fNwAJcIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2zQjHyvH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pinOTGoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jRpmTe22, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xWqiPCq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_44OoC0SX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_44OoC0SX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1h7CmfT, HV_BINOP_DIVIDE, 1, m, &cBinop_d1h7CmfT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4x1xPDhx_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_S5q8RPwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_zro1DZIU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gPVq6Wgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_S5q8RPwT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zro1DZIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1h7CmfT, HV_BINOP_DIVIDE, 0, m, &cBinop_d1h7CmfT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4x1xPDhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gPVq6Wgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_d1h7CmfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xt5KvYbi, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xt5KvYbi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xt5KvYbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fxBcuiJ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q0pk4Skz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_oaergAr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pe6CQNez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_7PmlEGcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7iRaoCWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_61NHxTTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_yIHdr9sg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yIHdr9sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xt5KvYbi, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xt5KvYbi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lr5jjXOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8mhXARoj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8mhXARoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xUVsEdyU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H0CzCmRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_16FhDCaA, 1, m, &cVar_16FhDCaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_16FhDCaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_67qDVBU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LQJ6EXYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jw4ovqyo, HV_BINOP_MULTIPLY, 1, m, &cBinop_jw4ovqyo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jSKofDGr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LQJ6EXYs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4hR9nDFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aI35ZS1Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aI35ZS1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shrqvlij, HV_BINOP_MULTIPLY, 1, m, &cBinop_shrqvlij_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oGli39DD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZvFbYBFm, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZvFbYBFm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NxOPSj61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oGli39DD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZWQo7Lkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iNzNowOH, HV_BINOP_MULTIPLY, 1, m, &cBinop_iNzNowOH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V5uClCEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_stpoKtzi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_stpoKtzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rw2HRWEP, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rw2HRWEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_h1ohX5rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AkiRZsoP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_61NHxTTH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xPqu0gRc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HIrriiED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Lr5jjXOF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q0pk4Skz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7PmlEGcx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fxBcuiJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_oaergAr4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_pe6CQNez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vmvdUYmF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7iRaoCWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6C7agtLx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EA3M6TVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1vqjxvL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xUVsEdyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8666yy2a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8666yy2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hC8KzAfh, HV_BINOP_MULTIPLY, 1, m, &cBinop_hC8KzAfh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hC8KzAfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6xnB3TiN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6xnB3TiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EA3M6TVd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_67qDVBU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wSvHlrdT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wSvHlrdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O5jOAgrC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_571sm8Nf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cjvbF9gw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WzaHv2Xz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d5L5Rqmr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_meMoL8dt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jw4ovqyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pe9Qjjl1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_shrqvlij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g1WWA1WR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZvFbYBFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TJ381csy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iNzNowOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fNwAJcIr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Rw2HRWEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pinOTGoa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Gq5etuX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h1ohX5rw, 0, m, &cVar_h1ohX5rw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v5OPXTvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HIrriiED, 1, m, &cVar_HIrriiED_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_meMoL8dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jw4ovqyo, HV_BINOP_MULTIPLY, 0, m, &cBinop_jw4ovqyo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WzaHv2Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZvFbYBFm, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZvFbYBFm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_O5jOAgrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_d5L5Rqmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shrqvlij, HV_BINOP_MULTIPLY, 0, m, &cBinop_shrqvlij_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cjvbF9gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iNzNowOH, HV_BINOP_MULTIPLY, 0, m, &cBinop_iNzNowOH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_571sm8Nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rw2HRWEP, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rw2HRWEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xPqu0gRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_16FhDCaA, 0, m, &cVar_16FhDCaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AkiRZsoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HIrriiED, 0, m, &cVar_HIrriiED_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GKoRf3Qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GUQqJU4s, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LuYJyEb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kMjfsphY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UDTLPR9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u40IXIkt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QBnizFv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dYPLvLZs, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1demcSfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3nEoWSCJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3nEoWSCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JlFIoUTR, HV_BINOP_DIVIDE, 1, m, &cBinop_JlFIoUTR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BF7NZpMU_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_EG4giiir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_P5DsG9ZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UzjyFojM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_EG4giiir_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P5DsG9ZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JlFIoUTR, HV_BINOP_DIVIDE, 0, m, &cBinop_JlFIoUTR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BF7NZpMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UzjyFojM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JlFIoUTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SgqucTaq, HV_BINOP_MULTIPLY, 1, m, &cBinop_SgqucTaq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SgqucTaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZTAIMpi3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qOvoEQIl_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_nrh7EmjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XCt8QRMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_jsuP952W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nIYCMCwW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3VVtwVg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zh6Jnoz4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zh6Jnoz4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SgqucTaq, HV_BINOP_MULTIPLY, 0, m, &cBinop_SgqucTaq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_31smJJ2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_pq6ri3CP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pq6ri3CP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y30TJoZq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_egIFnse8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eo0vi1TF, HV_BINOP_MULTIPLY, 1, m, &cBinop_eo0vi1TF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7mM8VFIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IuvJNLgO, 1, m, &cVar_IuvJNLgO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_opyx7ubJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQnhUI6K, HV_BINOP_MULTIPLY, 1, m, &cBinop_GQnhUI6K_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CB6P1fSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IiO60dLD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IiO60dLD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FEYLjTZa, HV_BINOP_MULTIPLY, 1, m, &cBinop_FEYLjTZa_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IuvJNLgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QjXnfxzC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_dsntRGu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_URiVilfB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3VVtwVg7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bs2r7fOM_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_3V0LZl4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_31smJJ2A_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZTAIMpi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_nrh7EmjE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qOvoEQIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jsuP952W_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_XCt8QRMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UuJIszpq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nIYCMCwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jSiCIRGJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_eijOQdBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8fuAb2Sf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Y30TJoZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_P89Ys6ZI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P89Ys6ZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPgmiaYO, HV_BINOP_MULTIPLY, 1, m, &cBinop_JPgmiaYO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JPgmiaYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WtWWqFU4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WtWWqFU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eijOQdBi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_QjXnfxzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VWpvHc3w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VWpvHc3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VRZUf983_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dJVbI8WR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XlQQ3mv2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uGktyEVq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XOenZNm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GKoRf3Qi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eo0vi1TF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LuYJyEb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GQnhUI6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UDTLPR9M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FEYLjTZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBnizFv8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pcSppMxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3V0LZl4N, 1, m, &cVar_3V0LZl4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JUBK6eCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dsntRGu8, 0, m, &cVar_dsntRGu8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_URiVilfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3V0LZl4N, 0, m, &cVar_3V0LZl4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Bs2r7fOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IuvJNLgO, 0, m, &cVar_IuvJNLgO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uGktyEVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XOenZNm5, HV_BINOP_MULTIPLY, 0, m, &cBinop_XOenZNm5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XlQQ3mv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eo0vi1TF, HV_BINOP_MULTIPLY, 0, m, &cBinop_eo0vi1TF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dJVbI8WR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQnhUI6K, HV_BINOP_MULTIPLY, 0, m, &cBinop_GQnhUI6K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VRZUf983_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FEYLjTZa, HV_BINOP_MULTIPLY, 0, m, &cBinop_FEYLjTZa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V5S5EOPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ki70oiwL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3sAKFJ0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32xyaus1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8MaY1JNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ypmsRwLx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XwxSeAJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DbB5wF6s, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RxSDc8W3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mujp5oLE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UElH4Jfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6UpstQpR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6UpstQpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1SQeXIPX, HV_BINOP_DIVIDE, 1, m, &cBinop_1SQeXIPX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nRGGBtN1_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_wA05liyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Qfw3EV7g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0yv7Olby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_wA05liyB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qfw3EV7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1SQeXIPX, HV_BINOP_DIVIDE, 0, m, &cBinop_1SQeXIPX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nRGGBtN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0yv7Olby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1SQeXIPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPMHCuEz, HV_BINOP_MULTIPLY, 1, m, &cBinop_JPMHCuEz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JPMHCuEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_keWGsgcp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TUzf9XKw_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_Q78Yfhwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1DCzUhit_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_SXnhR0UL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lhEXPGbT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_r2sO5RjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eY7gkrOD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eY7gkrOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPMHCuEz, HV_BINOP_MULTIPLY, 0, m, &cBinop_JPMHCuEz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_31bG69Nf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_zGSlIH5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zGSlIH5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nPQgcUaD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KmMb4DfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fVh2ys2S, HV_BINOP_MULTIPLY, 1, m, &cBinop_fVh2ys2S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e0rtb7g6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gCeA73FN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gCeA73FN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KmMb4DfV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0fJ33AOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ap7bwhU5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ap7bwhU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7meioSWQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_7meioSWQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AgsjV81I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAECJUXc, HV_BINOP_MULTIPLY, 1, m, &cBinop_JAECJUXc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EyigH7jv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wk0KjFFg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wk0KjFFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AgsjV81I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cHovdH32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LuIWSKvZ, 1, m, &cVar_LuIWSKvZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hTgJQckI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_56BLMODV, HV_BINOP_MULTIPLY, 1, m, &cBinop_56BLMODV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FJdo74YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_W5WhOYcq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W5WhOYcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z8pWAe3q, HV_BINOP_MULTIPLY, 1, m, &cBinop_z8pWAe3q_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_LuIWSKvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ymlw2HAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_P0w80moO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ammSsvv6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_r2sO5RjD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyn5g2B2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Wy6gNuZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_31bG69Nf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TUzf9XKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SXnhR0UL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_keWGsgcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Q78Yfhwy_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_1DCzUhit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BfZxmlGj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lhEXPGbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mdrdIGC2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_reGZcMZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_apcANYBb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_nPQgcUaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MgAw01qs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MgAw01qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JErNPv7o, HV_BINOP_MULTIPLY, 1, m, &cBinop_JErNPv7o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JErNPv7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_w3cAVp7c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w3cAVp7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_reGZcMZw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ymlw2HAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_S4oiAxBV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S4oiAxBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VH4GizPm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OBHe4Utx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sufjwLLj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SNCqo36r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_slr7mI4g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NXdD1qlY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fVh2ys2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V5S5EOPS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7meioSWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3sAKFJ0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JAECJUXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MaY1JNK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_56BLMODV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XwxSeAJv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_z8pWAe3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RxSDc8W3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_EMgm5cej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wy6gNuZs, 1, m, &cVar_Wy6gNuZs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4fo6K6Vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P0w80moO, 0, m, &cVar_P0w80moO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sufjwLLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_56BLMODV, HV_BINOP_MULTIPLY, 0, m, &cBinop_56BLMODV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VH4GizPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_SNCqo36r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JAECJUXc, HV_BINOP_MULTIPLY, 0, m, &cBinop_JAECJUXc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_slr7mI4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7meioSWQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_7meioSWQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NXdD1qlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fVh2ys2S, HV_BINOP_MULTIPLY, 0, m, &cBinop_fVh2ys2S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OBHe4Utx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z8pWAe3q, HV_BINOP_MULTIPLY, 0, m, &cBinop_z8pWAe3q_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iyn5g2B2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LuIWSKvZ, 0, m, &cVar_LuIWSKvZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ammSsvv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wy6gNuZs, 0, m, &cVar_Wy6gNuZs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S7J4ZTRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oi05mFKc, 1, m, &cIf_Oi05mFKc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BCHohtYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aDaQtmY7, m);
}

void Heavy_WSTD_DL3Y::cBinop_hlN05cl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCHohtYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pTIEbQKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Oi05mFKc, 0, m, &cIf_Oi05mFKc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_EQ3CZFqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_urGpZ7CD, HV_BINOP_DIVIDE, 0, m, &cBinop_urGpZ7CD_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8PJWEVa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPXAEZ9R, HV_BINOP_DIVIDE, 1, m, &cBinop_KPXAEZ9R_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_urGpZ7CD, HV_BINOP_DIVIDE, 1, m, &cBinop_urGpZ7CD_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_dCQtOrRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cmi2ZzzV, HV_BINOP_DIVIDE, 0, m, &cBinop_cmi2ZzzV_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_YCVCCKe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cmi2ZzzV, HV_BINOP_DIVIDE, 1, m, &cBinop_cmi2ZzzV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PMZx31QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8PJWEVa1, 0, m, &cVar_8PJWEVa1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yFmycH87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KPXAEZ9R, HV_BINOP_DIVIDE, 0, m, &cBinop_KPXAEZ9R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NrokZlJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EQ3CZFqb, 0, m, &cVar_EQ3CZFqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KPXAEZ9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_dCQtOrRK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_urGpZ7CD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_YCVCCKe3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cmi2ZzzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_SLL33Gwm_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_NFUxVrLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_9nq0lB1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sPbCN31e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_2DCfQeuO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SLL33Gwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sPbCN31e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2DCfQeuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_NFUxVrLz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9nq0lB1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ePG1RTd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_sWQ1u0dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DrHoDIlU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2BJPvc7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQR1Arck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_EVMHVwHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5AocJUtG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6ZDjpTJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iupqfkhQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_N4tih93S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_84jjLDL5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_OHqurMx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CpujEtEb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_oLCD6zst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_idNdUTBw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_NhsUxSOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Os08LIJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_07hesC6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fOMVGEvT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hHB05rRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OJkRaUIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vDByRBCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YDVr1jCW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_yaZBfMoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1vy4OKdJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vBaxypbm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L30b8PJo, 0, m, &cSlice_L30b8PJo_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_L30b8PJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QddBTBtR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QddBTBtR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BBRviKV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QddBTBtR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QddBTBtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Uyxy75y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_6cVSm3XH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FR9DPd7D, 0, m, &cSlice_FR9DPd7D_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TO2qQfB5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_FR9DPd7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tXgx9O1g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tXgx9O1g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_CtHHBQmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tXgx9O1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_tXgx9O1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lShH9u6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_cfwTj4tw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hq60Oppi, 0, m, &cSlice_hq60Oppi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vBaxypbm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_hq60Oppi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xEqz5vcU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xEqz5vcU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_7FKMgrML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xEqz5vcU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xEqz5vcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HrM5fwGJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lBYNyz7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_66bfk5fL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_66bfk5fL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_cXLbz4PG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_U3ppMwRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_doDSlRUY_sendMessage(_c, 0, m);
  cMsg_pIHZrUsM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_VYY1XBIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L08YFPGU_sendMessage(_c, 0, m);
  cMsg_zUigs1JX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cXLbz4PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_01zWeosO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_01zWeosO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Goz7w0TZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BXcqIxA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Goz7w0TZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_21XofZUX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BXcqIxA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ToJNJjK1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_21XofZUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TaFxQTMa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ToJNJjK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_e1c0cjid_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e1c0cjid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aQQUccjn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TaFxQTMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_U3ppMwRx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aQQUccjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_VYY1XBIW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DB2Q4jnC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nqGwf6iA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nqGwf6iA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_dch21zY0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dch21zY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7GceTZoU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7GceTZoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mO9oOthY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w6VR3GSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mO9oOthY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jwyVb3x5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_w6VR3GSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X40CBFX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jwyVb3x5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hgyOuWgp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X40CBFX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Cwa5Ii7o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Cwa5Ii7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5kHNwFDV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5kHNwFDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gSafWgT8_sendMessage(_c, 0, m);
  cMsg_qj4awV3J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hgyOuWgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zpTlYCTg_sendMessage(_c, 0, m);
  cMsg_tKx38LEg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5X8RkgbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8epfYC6P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8epfYC6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oyTE4VdW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jURPVExy_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tG8KpjXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_yFb36cxw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nEQILuNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3aVB2YGM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3aVB2YGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tb7EFxgH, HV_BINOP_DIVIDE, 1, m, &cBinop_Tb7EFxgH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oyTE4VdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PKuBD5jm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PKuBD5jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pSwUZzbP, m);
}

void Heavy_WSTD_DL3Y::cMsg_c5RFtsbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_r6yu4TXu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r6yu4TXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5X8RkgbX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jURPVExy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vbAXegNQ, m);
}

void Heavy_WSTD_DL3Y::cBinop_yFb36cxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_KJFI39MF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KJFI39MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tb7EFxgH, HV_BINOP_DIVIDE, 0, m, &cBinop_Tb7EFxgH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tb7EFxgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c5RFtsbW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7eFuURHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_pindiABO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pindiABO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6HoIMwtj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aHM7WBPO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MnglVKN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_id1LSqGM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IiCVVgNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7Ha2lz08_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7Ha2lz08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40GdEcMR, HV_BINOP_DIVIDE, 1, m, &cBinop_40GdEcMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6HoIMwtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_L45iSH3p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L45iSH3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lEnoaVt5, m);
}

void Heavy_WSTD_DL3Y::cMsg_1I7oQ7Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KpBWFtiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KpBWFtiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7eFuURHy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aHM7WBPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_f6dpVIu2, m);
}

void Heavy_WSTD_DL3Y::cBinop_id1LSqGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_fE6Gc2St_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fE6Gc2St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_40GdEcMR, HV_BINOP_DIVIDE, 0, m, &cBinop_40GdEcMR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_40GdEcMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1I7oQ7Rd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xVGmRWBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3QlUkMEs, HV_BINOP_MULTIPLY, 0, m, &cBinop_3QlUkMEs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oGZ9afmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tZiWRKYr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tZiWRKYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fp0QDSmK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3QlUkMEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pnFpHgBv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_otwNiRzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3QlUkMEs, HV_BINOP_MULTIPLY, 1, m, &cBinop_3QlUkMEs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fp0QDSmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_otwNiRzp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pnFpHgBv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jUQgV1PP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jUQgV1PP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qhvBe0Qz_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TyGI0rbR, m);
}

void Heavy_WSTD_DL3Y::cBinop_qhvBe0Qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lO4qK856, m);
}

void Heavy_WSTD_DL3Y::cVar_neS0EHoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hi3vO1eI, HV_BINOP_MULTIPLY, 0, m, &cBinop_Hi3vO1eI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f2czuKds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_y6zV42Wa_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_y6zV42Wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FkMT3l6u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Hi3vO1eI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SCzfpi9x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fJYMpjnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hi3vO1eI, HV_BINOP_MULTIPLY, 1, m, &cBinop_Hi3vO1eI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FkMT3l6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fJYMpjnV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SCzfpi9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MuTaNJPh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MuTaNJPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yAvxmJU1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Noj6rC6D, m);
}

void Heavy_WSTD_DL3Y::cBinop_yAvxmJU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QF7Oh31e, m);
}

void Heavy_WSTD_DL3Y::sEnv_mUEGhEzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pDKPgsZV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ybKkGat_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_REgfhzIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JB9f3HOr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3VJS1F8q_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_YSi4pXO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C5ZPcw3I, HV_BINOP_POW, 0, m, &cBinop_C5ZPcw3I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C5ZPcw3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tzgu9Hs6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8P5Hu7m0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vQEITEga_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pDKPgsZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LGlPOBzI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0ybKkGat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_REgfhzIh, 0, m, &cIf_REgfhzIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LGlPOBzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_REgfhzIh, 1, m, &cIf_REgfhzIh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3VJS1F8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_8P5Hu7m0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JB9f3HOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Tzgu9Hs6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vQEITEga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C5ZPcw3I, HV_BINOP_POW, 1, m, &cBinop_C5ZPcw3I_sendMessage);
  cMsg_YSi4pXO8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_spGo2FR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tBbHtJ4M, HV_BINOP_MULTIPLY, 0, m, &cBinop_tBbHtJ4M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_z7oOGZ7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WymrL3Zl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WymrL3Zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FpvKQ2W4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tBbHtJ4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_am43TAuq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OrnxlYSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tBbHtJ4M, HV_BINOP_MULTIPLY, 1, m, &cBinop_tBbHtJ4M_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FpvKQ2W4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OrnxlYSi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_am43TAuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aB69Xlc4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aB69Xlc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rcaFsAWR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MaOUQvBj, m);
}

void Heavy_WSTD_DL3Y::cBinop_rcaFsAWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qOtrtMXM, m);
}

void Heavy_WSTD_DL3Y::cMsg_Tzgu9Hs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_niEAADSy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_niEAADSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kJHkpQmY, m);
}

void Heavy_WSTD_DL3Y::sEnv_OwubAB32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ywBSmlFd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F71hN00W_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_csopc5F2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_D1aEGddi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VTMTMHV4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_mTu1YfG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRhAdYAb, HV_BINOP_POW, 0, m, &cBinop_DRhAdYAb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DRhAdYAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5I4bYUBX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gOC870RA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_TO8uoncx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ywBSmlFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TiahKUv1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F71hN00W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_csopc5F2, 0, m, &cIf_csopc5F2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TiahKUv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_csopc5F2, 1, m, &cIf_csopc5F2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VTMTMHV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_gOC870RA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D1aEGddi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_5I4bYUBX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TO8uoncx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRhAdYAb, HV_BINOP_POW, 1, m, &cBinop_DRhAdYAb_sendMessage);
  cMsg_mTu1YfG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_sqR7zGZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rMMqHpu, HV_BINOP_MULTIPLY, 0, m, &cBinop_1rMMqHpu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OTTYiGtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tUH2qtzC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tUH2qtzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XjQz00oH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1rMMqHpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QYdSYtAK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2twmmTNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rMMqHpu, HV_BINOP_MULTIPLY, 1, m, &cBinop_1rMMqHpu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XjQz00oH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2twmmTNK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QYdSYtAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KQgHujQ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KQgHujQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z5CGYRDr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UMA2RpvU, m);
}

void Heavy_WSTD_DL3Y::cBinop_z5CGYRDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pvv8SV8e, m);
}

void Heavy_WSTD_DL3Y::cMsg_5I4bYUBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_f070hltj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f070hltj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5j3oY51H, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_TO2qQfB5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eeev5Knv, 0, m, &cSlice_eeev5Knv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cfwTj4tw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eeev5Knv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kbmFn3Dc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kbmFn3Dc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_4V59JlPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kbmFn3Dc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kbmFn3Dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_onbMeAjM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_oRM0gaAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EBTZDPad_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EBTZDPad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_lwVjyTn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_0lkUAxVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0lkUAxVV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WXY0gOEs, 0, m, &cDelay_WXY0gOEs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0lkUAxVV, 0, m, &cDelay_0lkUAxVV_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kWtHoB3q, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_WXY0gOEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WXY0gOEs, m);
  cMsg_xt2mPPvQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Wz8yoMCs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ckNrR7mK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_xiaGepa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NJMwq2Xy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_8ivaAy2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V0mUEasC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0lkUAxVV, 2, m, &cDelay_0lkUAxVV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_184cT1PD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NJMwq2Xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8ivaAy2P, 0, m, &hTable_8ivaAy2P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lwVjyTn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_xiaGepa6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xt2mPPvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8ivaAy2P, 0, m, &hTable_8ivaAy2P_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_184cT1PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0lkUAxVV, 0, m, &cDelay_0lkUAxVV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_V0mUEasC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_WXY0gOEs, 2, m, &cDelay_WXY0gOEs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ckNrR7mK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kWtHoB3q, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_g9D7nTb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p6tPQp6N, HV_BINOP_SUBTRACT, 0, m, &cBinop_p6tPQp6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OCugrV3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XhCNM9Bn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XhCNM9Bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NSserWTx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xLJKtZYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcjDEAIl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_x1Qd8vB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_x1Qd8vB6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vhyepmZH, 0, m, &cDelay_vhyepmZH_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OpcZ7DJ1, 0, m, &sTabread_OpcZ7DJ1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_vhyepmZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vhyepmZH, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OpcZ7DJ1, 0, m, &sTabread_OpcZ7DJ1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vhyepmZH, 0, m, &cDelay_vhyepmZH_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_OpcZ7DJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RiBqSsFd, HV_BINOP_SUBTRACT, 0, m, &cBinop_RiBqSsFd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_LQSNRBRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQBqQHHK, HV_BINOP_MAX, 0, m, &cBinop_yQBqQHHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NSserWTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LQSNRBRE, HV_BINOP_MULTIPLY, 0, m, &cBinop_LQSNRBRE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p6tPQp6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MO7vgf5e_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OpcZ7DJ1, 0, m, &sTabread_OpcZ7DJ1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G7XKpTbp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_OOwcyaP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RiBqSsFd, HV_BINOP_SUBTRACT, 1, m, &cBinop_RiBqSsFd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vhyepmZH, 2, m, &cDelay_vhyepmZH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NcjDEAIl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OOwcyaP8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MO7vgf5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1Qd8vB6, 0, m, &cDelay_x1Qd8vB6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vhyepmZH, 0, m, &cDelay_vhyepmZH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lwCJ6uzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_yQBqQHHK, HV_BINOP_MAX, 1, m, &cBinop_yQBqQHHK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yQBqQHHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p6tPQp6N, HV_BINOP_SUBTRACT, 1, m, &cBinop_p6tPQp6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_G7XKpTbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1Qd8vB6, 0, m, &cDelay_x1Qd8vB6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dwSfmhaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x1Qd8vB6, 2, m, &cDelay_x1Qd8vB6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RiBqSsFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dwSfmhaI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tSbZTtV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xLJKtZYB, 0, m, &cVar_xLJKtZYB_sendMessage);
  cMsg_OCugrV3Y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_g9D7nTb0, 0, m, &cTabhead_g9D7nTb0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ug9XVbRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_e0gotVTP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_e0gotVTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_A9lBSK0N_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_EsfZTanh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EsfZTanh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GueQQom3, 0, m, &cDelay_GueQQom3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EsfZTanh, 0, m, &cDelay_EsfZTanh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_w2pURm5T, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_GueQQom3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GueQQom3, m);
  cMsg_4lGpX2ye_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iTlT0EyQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UHCukduy_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_muB88SNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RVbQecwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_ZZIezVNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0abpDmXO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_EsfZTanh, 2, m, &cDelay_EsfZTanh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fTvM0PNl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RVbQecwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZZIezVNP, 0, m, &hTable_ZZIezVNP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A9lBSK0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_muB88SNS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4lGpX2ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZZIezVNP, 0, m, &hTable_ZZIezVNP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fTvM0PNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EsfZTanh, 0, m, &cDelay_EsfZTanh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0abpDmXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_GueQQom3, 2, m, &cDelay_GueQQom3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UHCukduy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_w2pURm5T, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_uEvGtxQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QF0uedcH, HV_BINOP_SUBTRACT, 0, m, &cBinop_QF0uedcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DWcTHSyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JkZzOdMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JkZzOdMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0wOeHLnw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IoOkxZy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zFNGdlR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_lE9LUlt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lE9LUlt0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgeQ8eYf, 0, m, &cDelay_NgeQ8eYf_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xsaDvBh2, 0, m, &sTabread_xsaDvBh2_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_NgeQ8eYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NgeQ8eYf, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xsaDvBh2, 0, m, &sTabread_xsaDvBh2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgeQ8eYf, 0, m, &cDelay_NgeQ8eYf_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_xsaDvBh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_0524Z04m, HV_BINOP_SUBTRACT, 0, m, &cBinop_0524Z04m_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_EAGNSJ0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tSP9q0fD, HV_BINOP_MAX, 0, m, &cBinop_tSP9q0fD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0wOeHLnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EAGNSJ0h, HV_BINOP_MULTIPLY, 0, m, &cBinop_EAGNSJ0h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QF0uedcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jKyY5Ztu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xsaDvBh2, 0, m, &sTabread_xsaDvBh2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mkuZPReW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_nRqXaiQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0524Z04m, HV_BINOP_SUBTRACT, 1, m, &cBinop_0524Z04m_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgeQ8eYf, 2, m, &cDelay_NgeQ8eYf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zFNGdlR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nRqXaiQm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jKyY5Ztu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lE9LUlt0, 0, m, &cDelay_lE9LUlt0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NgeQ8eYf, 0, m, &cDelay_NgeQ8eYf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_veB9BQkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_tSP9q0fD, HV_BINOP_MAX, 1, m, &cBinop_tSP9q0fD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tSP9q0fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QF0uedcH, HV_BINOP_SUBTRACT, 1, m, &cBinop_QF0uedcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mkuZPReW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lE9LUlt0, 0, m, &cDelay_lE9LUlt0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2oIvVxyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lE9LUlt0, 2, m, &cDelay_lE9LUlt0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0524Z04m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2oIvVxyc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NanohraL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IoOkxZy6, 0, m, &cVar_IoOkxZy6_sendMessage);
  cMsg_DWcTHSyY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_uEvGtxQJ, 0, m, &cTabhead_uEvGtxQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_doDSlRUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PJfgcWfp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_L08YFPGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SiHkTrto, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zUigs1JX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vhIaCNiQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pIHZrUsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4eqeo5B2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tKx38LEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tYY3DqE4, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gSafWgT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9AMDrpsb, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zpTlYCTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_89DJZMCn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qj4awV3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rMRI8Z8T, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_QP8s1Kpl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b0wjchqk, 0, m, &cSlice_b0wjchqk_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_b0wjchqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WIgSkN4G_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WIgSkN4G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_DMHRrMQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WIgSkN4G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_WIgSkN4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zR6v04j2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_llUbHqBQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nnel99SE, 0, m, &cSlice_nnel99SE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8wD8kjlL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_nnel99SE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mP3taRuk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mP3taRuk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_mZHCjmU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mP3taRuk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_mP3taRuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mPh1lRLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ULqkOLTJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4nBsMKuA, 0, m, &cSlice_4nBsMKuA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QP8s1Kpl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_4nBsMKuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QqSrJohO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QqSrJohO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_KzPuhE96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QqSrJohO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QqSrJohO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mLMfzuBh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vtq9XRNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_UcOguTkJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UcOguTkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_LOOjKn8A_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_UHEOW3mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tWh1V07d_sendMessage(_c, 0, m);
  cMsg_jyPGKWCa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_FqW4PKGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SA7TVRUO_sendMessage(_c, 0, m);
  cMsg_ZSYaoQZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LOOjKn8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bOgcgbVQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bOgcgbVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3ROFHFjy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EnJ7kxg5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EnJ7kxg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJlfXbJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3ROFHFjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9IVhZj14_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9IVhZj14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UlzzPFIB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PJlfXbJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vU4OUScF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vU4OUScF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MfMVexsu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UlzzPFIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_UHEOW3mk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MfMVexsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_FqW4PKGG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dq4aJD8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vVm8k5WL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vVm8k5WL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_8Oroc8Ny_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8Oroc8Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iDwK5lN7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iDwK5lN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lxZErnkF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SO1M7WCs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SO1M7WCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EiTEqDqy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lxZErnkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6YEzesWU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6YEzesWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sK0RtvfZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EiTEqDqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_d6AdC5HA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d6AdC5HA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cDI63hc7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cDI63hc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArxGjwW4_sendMessage(_c, 0, m);
  cMsg_bmUOVrkO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sK0RtvfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eOj4Vc9V_sendMessage(_c, 0, m);
  cMsg_T2djgsPn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2tAA5g8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_guvlCCKF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_guvlCCKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lrDgyACy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Qyi8Gx6l_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uxgWOwXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_8Mjek0t5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jOtLh9dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MgCxTX46_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MgCxTX46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bRzI7dtG, HV_BINOP_DIVIDE, 1, m, &cBinop_bRzI7dtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lrDgyACy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sUbOEn8h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sUbOEn8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y7gZVT4Y, m);
}

void Heavy_WSTD_DL3Y::cMsg_aygJTBhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nEExu73Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nEExu73Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2tAA5g8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qyi8Gx6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_w7yg3Ipd, m);
}

void Heavy_WSTD_DL3Y::cBinop_8Mjek0t5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_MUGJMMSd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MUGJMMSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bRzI7dtG, HV_BINOP_DIVIDE, 0, m, &cBinop_bRzI7dtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bRzI7dtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aygJTBhZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TDHqeOpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_c2Ix2C9m_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c2Ix2C9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BHJCqgCx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BqYlUFUF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VUL8sCaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_VnCz794O_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AWtQ25Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CrQ1MQ4x_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CrQ1MQ4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0JsyIVfQ, HV_BINOP_DIVIDE, 1, m, &cBinop_0JsyIVfQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BHJCqgCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7YfTvWyq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7YfTvWyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HVsgKAIh, m);
}

void Heavy_WSTD_DL3Y::cMsg_bdcfEUlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_802eYiKg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_802eYiKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TDHqeOpz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BqYlUFUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x9LMNPBy, m);
}

void Heavy_WSTD_DL3Y::cBinop_VnCz794O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_77VrwmFH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_77VrwmFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0JsyIVfQ, HV_BINOP_DIVIDE, 0, m, &cBinop_0JsyIVfQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0JsyIVfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bdcfEUlG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_aIYCJqQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QwBfURPE, HV_BINOP_MULTIPLY, 0, m, &cBinop_QwBfURPE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YhidmvkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wH4xktwo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wH4xktwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KWJQkFSp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QwBfURPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XNZ2Lnq9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_68XkILje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QwBfURPE, HV_BINOP_MULTIPLY, 1, m, &cBinop_QwBfURPE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KWJQkFSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_68XkILje_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XNZ2Lnq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_f4wkuZR2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f4wkuZR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Di2dN8dl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7CoGcZtZ, m);
}

void Heavy_WSTD_DL3Y::cBinop_Di2dN8dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yvs9kQZU, m);
}

void Heavy_WSTD_DL3Y::cVar_YrgZFoYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_10b1Tuhq, HV_BINOP_MULTIPLY, 0, m, &cBinop_10b1Tuhq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AbbQ681a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OV6ljVUI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_OV6ljVUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wMRQ0hzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_10b1Tuhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QPiQYiiH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sVIg03Ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_10b1Tuhq, HV_BINOP_MULTIPLY, 1, m, &cBinop_10b1Tuhq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wMRQ0hzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_sVIg03Ii_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QPiQYiiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_FCBAOVha_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FCBAOVha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nQr8r7lR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bbwr9HIk, m);
}

void Heavy_WSTD_DL3Y::cBinop_nQr8r7lR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xWwoqGyP, m);
}

void Heavy_WSTD_DL3Y::sEnv_xlSxpIAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_337a6Kph_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3mPG2xqg_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_IcyW2LGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AkapiIyU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_w9F3Zps5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_fujE24ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EMuWUsj1, HV_BINOP_POW, 0, m, &cBinop_EMuWUsj1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EMuWUsj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3fCzRsCO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_N92SQm5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_NaVGO0bU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3mPG2xqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IcyW2LGM, 0, m, &cIf_IcyW2LGM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_337a6Kph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uXJXPkr5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uXJXPkr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IcyW2LGM, 1, m, &cIf_IcyW2LGM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w9F3Zps5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_N92SQm5w_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AkapiIyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_3fCzRsCO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NaVGO0bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EMuWUsj1, HV_BINOP_POW, 1, m, &cBinop_EMuWUsj1_sendMessage);
  cMsg_fujE24ze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CgSVQmn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KOTyq4Ui, HV_BINOP_MULTIPLY, 0, m, &cBinop_KOTyq4Ui_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XGXCwmSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_obR4dnlw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_obR4dnlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1xz1KzWA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KOTyq4Ui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gNKWixRm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6nlFkT7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KOTyq4Ui, HV_BINOP_MULTIPLY, 1, m, &cBinop_KOTyq4Ui_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1xz1KzWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6nlFkT7O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gNKWixRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gst0dhip_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gst0dhip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VDvGiPQn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jewdPNQr, m);
}

void Heavy_WSTD_DL3Y::cBinop_VDvGiPQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SF6GTxrf, m);
}

void Heavy_WSTD_DL3Y::cMsg_3fCzRsCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jJ1Za6tX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jJ1Za6tX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kACHp35I, m);
}

void Heavy_WSTD_DL3Y::sEnv_wprhuXSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qXpx4xZi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_359jod7s_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_H8saInOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_7JrIrfNk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WDPU5MSv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_jGjLna9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VoRxOAgp, HV_BINOP_POW, 0, m, &cBinop_VoRxOAgp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VoRxOAgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4yCIAHOF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_a8GSC4Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RXXImvA8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_359jod7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H8saInOc, 0, m, &cIf_H8saInOc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qXpx4xZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W5SB4FI2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W5SB4FI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_H8saInOc, 1, m, &cIf_H8saInOc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WDPU5MSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_a8GSC4Pg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7JrIrfNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_4yCIAHOF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RXXImvA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VoRxOAgp, HV_BINOP_POW, 1, m, &cBinop_VoRxOAgp_sendMessage);
  cMsg_jGjLna9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DezhKF6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VZbDzX7g, HV_BINOP_MULTIPLY, 0, m, &cBinop_VZbDzX7g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qnAIM47r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zynQ9YFq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_zynQ9YFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YeTHTkS5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VZbDzX7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_H9Kiu0S7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tF2HB7Os_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VZbDzX7g, HV_BINOP_MULTIPLY, 1, m, &cBinop_VZbDzX7g_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YeTHTkS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tF2HB7Os_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H9Kiu0S7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DE2psSOI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DE2psSOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_K37AlwBZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4cj1tFUE, m);
}

void Heavy_WSTD_DL3Y::cBinop_K37AlwBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5lDLb9pD, m);
}

void Heavy_WSTD_DL3Y::cMsg_4yCIAHOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uqVHnNQ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uqVHnNQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_o77aR6p6, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8wD8kjlL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5tmIUaGf, 0, m, &cSlice_5tmIUaGf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ULqkOLTJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_5tmIUaGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iplr1tr5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iplr1tr5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_XzNNo5RU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iplr1tr5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_iplr1tr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uoLKfGzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Xn21O91n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RKIcp54d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RKIcp54d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NCoNm3Wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_nVkDo0qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nVkDo0qT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_l9o7r3ju, 0, m, &cDelay_l9o7r3ju_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nVkDo0qT, 0, m, &cDelay_nVkDo0qT_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_liT688eE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_l9o7r3ju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l9o7r3ju, m);
  cMsg_k1P2Oqe8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7gRhpsrp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7YjGe974_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_dugzWNAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0dNUQd2o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_7JlqoA3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MqRRAcxO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nVkDo0qT, 2, m, &cDelay_nVkDo0qT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4UahCAsw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0dNUQd2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7JlqoA3H, 0, m, &hTable_7JlqoA3H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NCoNm3Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_dugzWNAU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_k1P2Oqe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7JlqoA3H, 0, m, &hTable_7JlqoA3H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4UahCAsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nVkDo0qT, 0, m, &cDelay_nVkDo0qT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MqRRAcxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_l9o7r3ju, 2, m, &cDelay_l9o7r3ju_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7YjGe974_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_liT688eE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_k7c2qPjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XCrrDLTO, HV_BINOP_SUBTRACT, 0, m, &cBinop_XCrrDLTO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_46KkKBG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Bn6h9PuE_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Bn6h9PuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AgAn6jwT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_pcqH1HmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tLsdtK6u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_A7FpN7b5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_A7FpN7b5, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BFtm417b, 0, m, &cDelay_BFtm417b_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rGRrRGcl, 0, m, &sTabread_rGRrRGcl_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_BFtm417b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BFtm417b, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rGRrRGcl, 0, m, &sTabread_rGRrRGcl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BFtm417b, 0, m, &cDelay_BFtm417b_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_rGRrRGcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Sa51FHhP, HV_BINOP_SUBTRACT, 0, m, &cBinop_Sa51FHhP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_D8VCG4sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2QyLrNPR, HV_BINOP_MAX, 0, m, &cBinop_2QyLrNPR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AgAn6jwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D8VCG4sC, HV_BINOP_MULTIPLY, 0, m, &cBinop_D8VCG4sC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XCrrDLTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oXdUGeRv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rGRrRGcl, 0, m, &sTabread_rGRrRGcl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T9JQRaBV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_MSctuCGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sa51FHhP, HV_BINOP_SUBTRACT, 1, m, &cBinop_Sa51FHhP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BFtm417b, 2, m, &cDelay_BFtm417b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tLsdtK6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MSctuCGm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oXdUGeRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_A7FpN7b5, 0, m, &cDelay_A7FpN7b5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BFtm417b, 0, m, &cDelay_BFtm417b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IWuD6iHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_2QyLrNPR, HV_BINOP_MAX, 1, m, &cBinop_2QyLrNPR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2QyLrNPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XCrrDLTO, HV_BINOP_SUBTRACT, 1, m, &cBinop_XCrrDLTO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_T9JQRaBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A7FpN7b5, 0, m, &cDelay_A7FpN7b5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HWYlXCvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_A7FpN7b5, 2, m, &cDelay_A7FpN7b5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sa51FHhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HWYlXCvP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RyEijl8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pcqH1HmT, 0, m, &cVar_pcqH1HmT_sendMessage);
  cMsg_46KkKBG9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_k7c2qPjO, 0, m, &cTabhead_k7c2qPjO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aboNlKgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xXeEXPg7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_xXeEXPg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GFQxy6na_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_O4uiejDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O4uiejDB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xjFsEJIH, 0, m, &cDelay_xjFsEJIH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O4uiejDB, 0, m, &cDelay_O4uiejDB_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HK8kvjCy, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_xjFsEJIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xjFsEJIH, m);
  cMsg_MJ7fbKkl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OsArD399_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zCKazLwt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_N7QGB4vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CCgU0xAQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_bLqgvycv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gx6vp97U_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O4uiejDB, 2, m, &cDelay_O4uiejDB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZemajuRU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CCgU0xAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bLqgvycv, 0, m, &hTable_bLqgvycv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GFQxy6na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_N7QGB4vk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MJ7fbKkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bLqgvycv, 0, m, &hTable_bLqgvycv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZemajuRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_O4uiejDB, 0, m, &cDelay_O4uiejDB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gx6vp97U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xjFsEJIH, 2, m, &cDelay_xjFsEJIH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zCKazLwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_HK8kvjCy, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_4A8SDNXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Zd8E4pQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_7Zd8E4pQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vfNgblhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vpnzZiBq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vpnzZiBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Q2TsqhPJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_cdd5NsBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJWzP79k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_H6jyPt6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_H6jyPt6B, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3aHdUF8P, 0, m, &cDelay_3aHdUF8P_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EascK7nt, 0, m, &sTabread_EascK7nt_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_3aHdUF8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3aHdUF8P, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EascK7nt, 0, m, &sTabread_EascK7nt_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3aHdUF8P, 0, m, &cDelay_3aHdUF8P_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_EascK7nt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_kg7gr3E6, HV_BINOP_SUBTRACT, 0, m, &cBinop_kg7gr3E6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Ugp6S1MG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Hs0gTSN, HV_BINOP_MAX, 0, m, &cBinop_7Hs0gTSN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q2TsqhPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ugp6S1MG, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ugp6S1MG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Zd8E4pQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yb1U6Op4_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_EascK7nt, 0, m, &sTabread_EascK7nt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yww9VXvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hRoiEBnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kg7gr3E6, HV_BINOP_SUBTRACT, 1, m, &cBinop_kg7gr3E6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3aHdUF8P, 2, m, &cDelay_3aHdUF8P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FJWzP79k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hRoiEBnQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Yb1U6Op4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6jyPt6B, 0, m, &cDelay_H6jyPt6B_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3aHdUF8P, 0, m, &cDelay_3aHdUF8P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RMI9qqkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Hs0gTSN, HV_BINOP_MAX, 1, m, &cBinop_7Hs0gTSN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Hs0gTSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7Zd8E4pQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_7Zd8E4pQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Yww9VXvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6jyPt6B, 0, m, &cDelay_H6jyPt6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jTmz8f28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_H6jyPt6B, 2, m, &cDelay_H6jyPt6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kg7gr3E6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jTmz8f28_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SFKSfCqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cdd5NsBa, 0, m, &cVar_cdd5NsBa_sendMessage);
  cMsg_vfNgblhT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4A8SDNXc, 0, m, &cTabhead_4A8SDNXc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tWh1V07d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VjRAC79J, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SA7TVRUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FrEBcdQy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZSYaoQZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WNHKtmXy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jyPGKWCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v4eVq6Rx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_T2djgsPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jEJ6ZPTA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ArxGjwW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PamYQFoh, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eOj4Vc9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9EKY0QTN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bmUOVrkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mk0ijScY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_pPD9hHEE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OmOATDNE, 0, m, &cSlice_OmOATDNE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_OmOATDNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wVnrXCwN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wVnrXCwN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_2CXvN2eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wVnrXCwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_wVnrXCwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uKCJR26i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KctIUay8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V1gBiR2S, 0, m, &cSlice_V1gBiR2S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_s5S601jr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_V1gBiR2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TCdTCLaK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TCdTCLaK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_MHprr7mE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TCdTCLaK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_TCdTCLaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_x13ud81Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_deI0MIi6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ER1QuOYL, 0, m, &cSlice_ER1QuOYL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pPD9hHEE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ER1QuOYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iOGZY3k4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iOGZY3k4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GjAneATj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iOGZY3k4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_iOGZY3k4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1NZrvZDg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IgPwZqxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_vbBVxnF5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vbBVxnF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AmXLnuV8_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_EuVtVvT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9XmYzd5p_sendMessage(_c, 0, m);
  cMsg_hhbcF1Gw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_3JTt82og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JQxPl7R6_sendMessage(_c, 0, m);
  cMsg_Vqz3O8ve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AmXLnuV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tCfnrkyb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tCfnrkyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t1zFETkj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vZc5N6VA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t1zFETkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_l74OrfJQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vZc5N6VA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5iUtktJx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_l74OrfJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jLq9ehU6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5iUtktJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_l4lo1s3f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l4lo1s3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xNDzPDIF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jLq9ehU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_EuVtVvT5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xNDzPDIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_3JTt82og_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bgIVQUql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Ui1cMVLj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ui1cMVLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_8ulSS5CL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8ulSS5CL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MC4CVhoT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MC4CVhoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9xARpxVK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tezchNHv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tezchNHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gYNE2H9s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9xARpxVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_o31r1IGd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o31r1IGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HTpb6Dg1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gYNE2H9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UEpXBnkH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UEpXBnkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_z3ZIDQgu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z3ZIDQgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rdoQFana_sendMessage(_c, 0, m);
  cMsg_XmCKpJGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HTpb6Dg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wdNzOHaZ_sendMessage(_c, 0, m);
  cMsg_aCkdEMzQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cK6RgHPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nzSJQu1r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nzSJQu1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oU6fFsAt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6kYlvTuW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_82AhKPIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_dKr89wmO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ldks9WMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3mzRXghH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3mzRXghH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_trHgM645, HV_BINOP_DIVIDE, 1, m, &cBinop_trHgM645_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oU6fFsAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Scw6rCdY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Scw6rCdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Y4kAoy2n, m);
}

void Heavy_WSTD_DL3Y::cMsg_d0sz0vBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6Y39ZHie_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Y39ZHie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cK6RgHPc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6kYlvTuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fS4nUlFd, m);
}

void Heavy_WSTD_DL3Y::cBinop_dKr89wmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_n4GaVavJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n4GaVavJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_trHgM645, HV_BINOP_DIVIDE, 0, m, &cBinop_trHgM645_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_trHgM645_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d0sz0vBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Yz5EVJsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_sbR1cFvh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sbR1cFvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LnIVkgCr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TIU0ZuXZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_O2M1j7XT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_uv4cKE8V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PvtMhvYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pEb9pjmC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pEb9pjmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAPIgLiL, HV_BINOP_DIVIDE, 1, m, &cBinop_xAPIgLiL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LnIVkgCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EqtcBsJ2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EqtcBsJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_aMDV5QhE, m);
}

void Heavy_WSTD_DL3Y::cMsg_CjTOKMrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EDdPU8uh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EDdPU8uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Yz5EVJsU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TIU0ZuXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GmJxjfg8, m);
}

void Heavy_WSTD_DL3Y::cBinop_uv4cKE8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_8kBShX79_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8kBShX79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAPIgLiL, HV_BINOP_DIVIDE, 0, m, &cBinop_xAPIgLiL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xAPIgLiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CjTOKMrQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cJ1mKNky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqNM74DB, HV_BINOP_MULTIPLY, 0, m, &cBinop_JqNM74DB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jSUxIPvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kihpMsjJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kihpMsjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92qsufgu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JqNM74DB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XSw2rlC9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GzPCzpbA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JqNM74DB, HV_BINOP_MULTIPLY, 1, m, &cBinop_JqNM74DB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_92qsufgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GzPCzpbA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XSw2rlC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9MpQDbof_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9MpQDbof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_oPX4D1bf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_M5x0W8ZR, m);
}

void Heavy_WSTD_DL3Y::cBinop_oPX4D1bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_iYDU982g, m);
}

void Heavy_WSTD_DL3Y::cVar_JEv7cZTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PGnIXsGC, HV_BINOP_MULTIPLY, 0, m, &cBinop_PGnIXsGC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7rYngTTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KXyaklhs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KXyaklhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zbS7Wi7b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PGnIXsGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_01cf5bUG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Oc27QvBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PGnIXsGC, HV_BINOP_MULTIPLY, 1, m, &cBinop_PGnIXsGC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zbS7Wi7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Oc27QvBG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_01cf5bUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ueDtrYl2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ueDtrYl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MH4PEnil_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fpRf9nTM, m);
}

void Heavy_WSTD_DL3Y::cBinop_MH4PEnil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FMWm79cD, m);
}

void Heavy_WSTD_DL3Y::sEnv_sP9ygMXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i0y2vdeJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RHM4NjKX_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_mzcwXbub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_nlVpXDqE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Hce7nd7s_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_hgxYupWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1BJPWF1X, HV_BINOP_POW, 0, m, &cBinop_1BJPWF1X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1BJPWF1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PQXYXtSY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rPjDM3K4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_VkMcvkgs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_i0y2vdeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1S52V71v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RHM4NjKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mzcwXbub, 0, m, &cIf_mzcwXbub_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1S52V71v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mzcwXbub, 1, m, &cIf_mzcwXbub_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hce7nd7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_rPjDM3K4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nlVpXDqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_PQXYXtSY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VkMcvkgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1BJPWF1X, HV_BINOP_POW, 1, m, &cBinop_1BJPWF1X_sendMessage);
  cMsg_hgxYupWU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6shtn7IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F35kgNJW, HV_BINOP_MULTIPLY, 0, m, &cBinop_F35kgNJW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gJKDR1mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XpPpxU9V_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XpPpxU9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bfCn1ftz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_F35kgNJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qQ89JeYy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B2pXcPu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F35kgNJW, HV_BINOP_MULTIPLY, 1, m, &cBinop_F35kgNJW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bfCn1ftz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B2pXcPu7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qQ89JeYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_WbM5taex_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WbM5taex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UiMZrZX7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8JSg4GyH, m);
}

void Heavy_WSTD_DL3Y::cBinop_UiMZrZX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Xd6Pj0ju, m);
}

void Heavy_WSTD_DL3Y::cMsg_PQXYXtSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AODsaEQC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AODsaEQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dFSQ4B9D, m);
}

void Heavy_WSTD_DL3Y::sEnv_5JrByhW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XA7xN4ct_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5AVDtmTH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_D8L2vKih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tl3oqrUp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LPOAmJKC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_uceRVnaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nqK3CUUR, HV_BINOP_POW, 0, m, &cBinop_nqK3CUUR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nqK3CUUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_clDXE23S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vcNj9zhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_kuU08h7y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XA7xN4ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_aKiYNpCr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5AVDtmTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D8L2vKih, 0, m, &cIf_D8L2vKih_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aKiYNpCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D8L2vKih, 1, m, &cIf_D8L2vKih_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LPOAmJKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vcNj9zhl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tl3oqrUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_clDXE23S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kuU08h7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nqK3CUUR, HV_BINOP_POW, 1, m, &cBinop_nqK3CUUR_sendMessage);
  cMsg_uceRVnaY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_A0XliZu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ABmds010, HV_BINOP_MULTIPLY, 0, m, &cBinop_ABmds010_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BlcFFNxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ez5DtDOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ez5DtDOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sZIoTgSr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ABmds010_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5YSOQAku_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2m9tHm3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ABmds010, HV_BINOP_MULTIPLY, 1, m, &cBinop_ABmds010_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sZIoTgSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2m9tHm3D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5YSOQAku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IUlITmoO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IUlITmoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_f3k36W1E_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_p7c9rDB8, m);
}

void Heavy_WSTD_DL3Y::cBinop_f3k36W1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8NArlSep, m);
}

void Heavy_WSTD_DL3Y::cMsg_clDXE23S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2mKjRY3W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2mKjRY3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sAYI7Glt, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_s5S601jr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bhjBudMt, 0, m, &cSlice_bhjBudMt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_deI0MIi6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_bhjBudMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_h7mUtuoq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_h7mUtuoq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tXMnp2tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h7mUtuoq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_h7mUtuoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gRxaeJAI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_flsKzghA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Rqppa6yf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Rqppa6yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_nsEeNcim_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_pFNjuVqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pFNjuVqQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y3WIKYSW, 0, m, &cDelay_Y3WIKYSW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pFNjuVqQ, 0, m, &cDelay_pFNjuVqQ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_I1NZKkvd, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Y3WIKYSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y3WIKYSW, m);
  cMsg_I1GYflEC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_AHWStBz7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_33aGStUY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_2MPNa3Cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HyRgPKSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_9oOiDax1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x720fOuP_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pFNjuVqQ, 2, m, &cDelay_pFNjuVqQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3uICfXTM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HyRgPKSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_9oOiDax1, 0, m, &hTable_9oOiDax1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nsEeNcim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_2MPNa3Cp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I1GYflEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_9oOiDax1, 0, m, &hTable_9oOiDax1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3uICfXTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pFNjuVqQ, 0, m, &cDelay_pFNjuVqQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_x720fOuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y3WIKYSW, 2, m, &cDelay_Y3WIKYSW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_33aGStUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_I1NZKkvd, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_tmhNnqU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3pULWc1C, HV_BINOP_SUBTRACT, 0, m, &cBinop_3pULWc1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dLdUYz7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IX3kr7B3_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IX3kr7B3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_caJqSCef_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_17NCJ1Qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0BnLM6Y3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_HWgBRcQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HWgBRcQH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHkkLIPw, 0, m, &cDelay_FHkkLIPw_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4yWhuYWi, 0, m, &sTabread_4yWhuYWi_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_FHkkLIPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FHkkLIPw, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4yWhuYWi, 0, m, &sTabread_4yWhuYWi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHkkLIPw, 0, m, &cDelay_FHkkLIPw_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_4yWhuYWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_GnGE3FGj, HV_BINOP_SUBTRACT, 0, m, &cBinop_GnGE3FGj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_ghd1wTsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppztfoLc, HV_BINOP_MAX, 0, m, &cBinop_ppztfoLc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_caJqSCef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghd1wTsN, HV_BINOP_MULTIPLY, 0, m, &cBinop_ghd1wTsN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3pULWc1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OPNoh90K_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4yWhuYWi, 0, m, &sTabread_4yWhuYWi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RZKSCtBi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UKBlvWsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GnGE3FGj, HV_BINOP_SUBTRACT, 1, m, &cBinop_GnGE3FGj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHkkLIPw, 2, m, &cDelay_FHkkLIPw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0BnLM6Y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UKBlvWsm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OPNoh90K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWgBRcQH, 0, m, &cDelay_HWgBRcQH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FHkkLIPw, 0, m, &cDelay_FHkkLIPw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_C4SzMZ0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ppztfoLc, HV_BINOP_MAX, 1, m, &cBinop_ppztfoLc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ppztfoLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3pULWc1C, HV_BINOP_SUBTRACT, 1, m, &cBinop_3pULWc1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RZKSCtBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWgBRcQH, 0, m, &cDelay_HWgBRcQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J76xwsw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HWgBRcQH, 2, m, &cDelay_HWgBRcQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GnGE3FGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J76xwsw6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GRpRkIBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_17NCJ1Qe, 0, m, &cVar_17NCJ1Qe_sendMessage);
  cMsg_dLdUYz7C_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_tmhNnqU2, 0, m, &cTabhead_tmhNnqU2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gPGshhmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KGGeSIL4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KGGeSIL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_01VfVAYz_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_D9vJF4bA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D9vJF4bA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DaIdrnE8, 0, m, &cDelay_DaIdrnE8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D9vJF4bA, 0, m, &cDelay_D9vJF4bA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lezgKYhk, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_DaIdrnE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DaIdrnE8, m);
  cMsg_8YHIqPyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ObFfj4hU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_7RtG0eWB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_qYMeLPBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9kArZHzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_8gImk5Wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oB9ChnX2_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_D9vJF4bA, 2, m, &cDelay_D9vJF4bA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_klxkxxbq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9kArZHzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8gImk5Wj, 0, m, &hTable_8gImk5Wj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_01VfVAYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_qYMeLPBa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8YHIqPyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8gImk5Wj, 0, m, &hTable_8gImk5Wj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_klxkxxbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D9vJF4bA, 0, m, &cDelay_D9vJF4bA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oB9ChnX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_DaIdrnE8, 2, m, &cDelay_DaIdrnE8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7RtG0eWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lezgKYhk, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_hJbtUJxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_imYjl6n4, HV_BINOP_SUBTRACT, 0, m, &cBinop_imYjl6n4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hte53JU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BSkmEkPA_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_BSkmEkPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_LBnkX255_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oyf3QO4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4KJiCvnD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_0nW09Gir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0nW09Gir, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pkofargY, 0, m, &cDelay_pkofargY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TUNlizre, 0, m, &sTabread_TUNlizre_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_pkofargY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pkofargY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TUNlizre, 0, m, &sTabread_TUNlizre_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pkofargY, 0, m, &cDelay_pkofargY_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_TUNlizre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fscvRkxN, HV_BINOP_SUBTRACT, 0, m, &cBinop_fscvRkxN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_VewR3gJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9yPXQO6B, HV_BINOP_MAX, 0, m, &cBinop_9yPXQO6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LBnkX255_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VewR3gJE, HV_BINOP_MULTIPLY, 0, m, &cBinop_VewR3gJE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_imYjl6n4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nsYSXRHx_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_TUNlizre, 0, m, &sTabread_TUNlizre_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ti4QhyGK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fgVA2eb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fscvRkxN, HV_BINOP_SUBTRACT, 1, m, &cBinop_fscvRkxN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pkofargY, 2, m, &cDelay_pkofargY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4KJiCvnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fgVA2eb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nsYSXRHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0nW09Gir, 0, m, &cDelay_0nW09Gir_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_pkofargY, 0, m, &cDelay_pkofargY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FsD9SGp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9yPXQO6B, HV_BINOP_MAX, 1, m, &cBinop_9yPXQO6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9yPXQO6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_imYjl6n4, HV_BINOP_SUBTRACT, 1, m, &cBinop_imYjl6n4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ti4QhyGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0nW09Gir, 0, m, &cDelay_0nW09Gir_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t2vds5Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0nW09Gir, 2, m, &cDelay_0nW09Gir_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fscvRkxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_t2vds5Pa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ULAoPm1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oyf3QO4Y, 0, m, &cVar_oyf3QO4Y_sendMessage);
  cMsg_hte53JU8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hJbtUJxh, 0, m, &cTabhead_hJbtUJxh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9XmYzd5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9gNqvxe8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JQxPl7R6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D8o1IQ9a, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Vqz3O8ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zcdZoue6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hhbcF1Gw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z9mAmBX2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_aCkdEMzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CQP4Afrq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rdoQFana_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hePoyE3C, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wdNzOHaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TrYhwPa5, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XmCKpJGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2DiqvxBr, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_0iOdc2E1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XzBsE0Sf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ffB7KE2O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0X6IIUai_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XzBsE0Sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0iOdc2E1, 1, m, &cVar_0iOdc2E1_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_IPn2yIfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2BJPvc7U, 0, m, &cVar_2BJPvc7U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_iMrWqOsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2BJPvc7U, 0, m, &cVar_2BJPvc7U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_s4AwjXm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iMrWqOsq, 0, m, &cIf_iMrWqOsq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_R23fXq5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IPn2yIfd, 0, m, &cIf_IPn2yIfd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_SFttxh9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qulw3rfR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_l9zhszfd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jSq1NmVi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qulw3rfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SFttxh9i, 1, m, &cVar_SFttxh9i_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_09DjQoN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_OHqurMx3, 0, m, &cVar_OHqurMx3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_PtL9VEmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_OHqurMx3, 0, m, &cVar_OHqurMx3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Cbbdjo1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PtL9VEmS, 0, m, &cIf_PtL9VEmS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CowyJzkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_09DjQoN6, 0, m, &cIf_09DjQoN6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_d7Leqv0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JSVusPru_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PnVc4aDO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Pu2cKekL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JSVusPru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d7Leqv0V, 1, m, &cVar_d7Leqv0V_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_nrvgTTcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hHB05rRo, 0, m, &cVar_hHB05rRo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_4h1IrHQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hHB05rRo, 0, m, &cVar_hHB05rRo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_6bm554UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4h1IrHQd, 0, m, &cIf_4h1IrHQd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_VPRQAEvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrvgTTcx, 0, m, &cIf_nrvgTTcx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_z1M0czwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cEy7lamz, HV_BINOP_DIVIDE, 0, m, &cBinop_cEy7lamz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xTARVGZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kEcG9gC9, HV_BINOP_MULTIPLY, 1, m, &cBinop_kEcG9gC9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_hCG6auo7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nmqJB38J, 0, m, &cSlice_nmqJB38J_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6fPuX4ug, 0, m, &cSlice_6fPuX4ug_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CG3zXQGZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RV88tVPb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_nmqJB38J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_wGV5d0fX, 0, m, &cVar_wGV5d0fX_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_wGV5d0fX, 0, m, &cVar_wGV5d0fX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_6fPuX4ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1feUHurt, HV_BINOP_NEQ, 1, m, &cBinop_1feUHurt_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wGV5d0fX, 1, m, &cVar_wGV5d0fX_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1feUHurt, HV_BINOP_NEQ, 1, m, &cBinop_1feUHurt_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_wGV5d0fX, 1, m, &cVar_wGV5d0fX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wGV5d0fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_6LrdmchT_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_D5CDU2mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_anA3HkOL_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_99Vpp13l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_99Vpp13l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wGV5d0fX, 0, m, &cVar_wGV5d0fX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_anA3HkOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1feUHurt, HV_BINOP_NEQ, 1, m, &cBinop_1feUHurt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1feUHurt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D5CDU2mp, 1, m, &cIf_D5CDU2mp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RV88tVPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_D5CDU2mp, 0, m, &cIf_D5CDU2mp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CG3zXQGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1feUHurt, HV_BINOP_NEQ, 0, m, &cBinop_1feUHurt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tcdhWlqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lz0aQicf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JjIxLBZr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vR3JrWf4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LDXg6dUG_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1FHs5EeQ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9nKsIfl5_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i3mABKgc_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uImSmZyl_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0nQjxD9c_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PFFcyIt5_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rOyT6HD7_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6TBHmHSt_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LltvlPfJ_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qjOnfChG_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FRpjqGhz_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ogB6UPcs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_LDXg6dUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nE1xdfrY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_1FHs5EeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P347kS5c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9nKsIfl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kG8o5Rpm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_i3mABKgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GfhqfSF8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uImSmZyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bG1fXx7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0nQjxD9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sw9vPmmG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PFFcyIt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dtR7NtxW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rOyT6HD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vQyBbPg5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6TBHmHSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_njLNEsI3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LltvlPfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_igDIN4Hb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qjOnfChG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aU4lvr27_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_FRpjqGhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0nfPJlJw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ogB6UPcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2KdpStqX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cEy7lamz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kEcG9gC9, HV_BINOP_MULTIPLY, 0, m, &cBinop_kEcG9gC9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kEcG9gC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hCG6auo7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_JjIxLBZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z1M0czwq, 0, m, &cVar_z1M0czwq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xTARVGZM, 0, m, &cVar_xTARVGZM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lz0aQicf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cEy7lamz, HV_BINOP_DIVIDE, 1, m, &cBinop_cEy7lamz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_08f1A9N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z1M0czwq, 0, m, &cVar_z1M0czwq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_czwZZxRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xTARVGZM, 0, m, &cVar_xTARVGZM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nE1xdfrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P347kS5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kG8o5Rpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GfhqfSF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bG1fXx7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sw9vPmmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dtR7NtxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vQyBbPg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_njLNEsI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_igDIN4Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aU4lvr27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0nfPJlJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2KdpStqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_czwZZxRQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_08f1A9N8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_kMaiPoXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPSBvHuu, HV_BINOP_DIVIDE, 0, m, &cBinop_BPSBvHuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GCEMjEK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YkGkAadO, HV_BINOP_MULTIPLY, 1, m, &cBinop_YkGkAadO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_t8097Bua_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aOP32ccM, 0, m, &cSlice_aOP32ccM_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_na8xKPsm, 0, m, &cSlice_na8xKPsm_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U2xd3bIi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q9VAT381_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_aOP32ccM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_HoTBaWYB, 0, m, &cVar_HoTBaWYB_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_HoTBaWYB, 0, m, &cVar_HoTBaWYB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_na8xKPsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fk2MClbO, HV_BINOP_NEQ, 1, m, &cBinop_fk2MClbO_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_HoTBaWYB, 1, m, &cVar_HoTBaWYB_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_fk2MClbO, HV_BINOP_NEQ, 1, m, &cBinop_fk2MClbO_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_HoTBaWYB, 1, m, &cVar_HoTBaWYB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_HoTBaWYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_x8GsenMU_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_b27hPo8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7de3q0jW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9BHfuxn1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_9BHfuxn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HoTBaWYB, 0, m, &cVar_HoTBaWYB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7de3q0jW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fk2MClbO, HV_BINOP_NEQ, 1, m, &cBinop_fk2MClbO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fk2MClbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b27hPo8H, 1, m, &cIf_b27hPo8H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q9VAT381_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b27hPo8H, 0, m, &cIf_b27hPo8H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U2xd3bIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fk2MClbO, HV_BINOP_NEQ, 0, m, &cBinop_fk2MClbO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_bamSgTOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YkCr0V7c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q9nZgmVX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_YAkRztSv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QIdqiW3t_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8cLPR3QS_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aqTnV5FF_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HOHp947p_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9LZ2T1ms_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IJUTT9vq_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mULl6GI3_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fimt5fem_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_icspUBte_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mkciyxiw_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GJXEgGx8_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GMZTcE55_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yFm0TmPR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_QIdqiW3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P6ZYuMy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_8cLPR3QS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0GRj0uBj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aqTnV5FF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LVqGbD2U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HOHp947p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uKtIVvG6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9LZ2T1ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wEWF9HAl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IJUTT9vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xaDRyCNJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mULl6GI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LdK2m3AI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Fimt5fem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o9Q2dXwD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_icspUBte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O5QV0MTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mkciyxiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xNUfCxbv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GJXEgGx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aIFKelI7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GMZTcE55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ZHTR5TF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yFm0TmPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Frs6aDJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BPSBvHuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YkGkAadO, HV_BINOP_MULTIPLY, 0, m, &cBinop_YkGkAadO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YkGkAadO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_t8097Bua_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_YkCr0V7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPSBvHuu, HV_BINOP_DIVIDE, 1, m, &cBinop_BPSBvHuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q9nZgmVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kMaiPoXH, 0, m, &cVar_kMaiPoXH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GCEMjEK3, 0, m, &cVar_GCEMjEK3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OcWu5CDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GCEMjEK3, 0, m, &cVar_GCEMjEK3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OckkOPuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kMaiPoXH, 0, m, &cVar_kMaiPoXH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P6ZYuMy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0GRj0uBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LVqGbD2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uKtIVvG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wEWF9HAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xaDRyCNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LdK2m3AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o9Q2dXwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O5QV0MTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xNUfCxbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aIFKelI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4ZHTR5TF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Frs6aDJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcWu5CDu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OckkOPuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FNOxbhKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BULf5Hsz, HV_BINOP_DIVIDE, 0, m, &cBinop_BULf5Hsz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RuYHqKoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZTUeKpU, HV_BINOP_MULTIPLY, 1, m, &cBinop_TZTUeKpU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8Q0ppjS0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5SDmrm5X, 0, m, &cSlice_5SDmrm5X_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6bnTFrr2, 0, m, &cSlice_6bnTFrr2_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x3GQWwpK_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9GOfT7w7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_5SDmrm5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_SSCt4e1g, 0, m, &cVar_SSCt4e1g_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_SSCt4e1g, 0, m, &cVar_SSCt4e1g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_6bnTFrr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ozzD3Q2W, HV_BINOP_NEQ, 1, m, &cBinop_ozzD3Q2W_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_SSCt4e1g, 1, m, &cVar_SSCt4e1g_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_ozzD3Q2W, HV_BINOP_NEQ, 1, m, &cBinop_ozzD3Q2W_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_SSCt4e1g, 1, m, &cVar_SSCt4e1g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_SSCt4e1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_tFHqFCKv_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_v7hPHK2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3auHAtnR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LW1jVesD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_3auHAtnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ozzD3Q2W, HV_BINOP_NEQ, 1, m, &cBinop_ozzD3Q2W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_LW1jVesD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SSCt4e1g, 0, m, &cVar_SSCt4e1g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ozzD3Q2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v7hPHK2T, 1, m, &cIf_v7hPHK2T_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x3GQWwpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ozzD3Q2W, HV_BINOP_NEQ, 0, m, &cBinop_ozzD3Q2W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9GOfT7w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v7hPHK2T, 0, m, &cIf_v7hPHK2T_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_V6TBUuQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1LEO2byc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p3BRFhk6_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RKRM3S28_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gMmXkkaw_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R1Jqtkri_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3sCCpg0m_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JbJWuGId_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zx31n2P3_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TXFYQKRL_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TDgdtlKa_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IyhlM8at_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0VzWxNED_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aejdt4UE_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rFvK1vmQ_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sx8AnjRP_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E6xkDigS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_gMmXkkaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ef3GSH23_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_R1Jqtkri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lvhWdRPK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3sCCpg0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UatzpFj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JbJWuGId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jBqIad4Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Zx31n2P3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n3U3kXog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_TXFYQKRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_itKM7yf1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_TDgdtlKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iRmWU4si_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IyhlM8at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vaRZMWfR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0VzWxNED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7tFHIjdr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aejdt4UE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YzcBkNh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rFvK1vmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nEm829Tz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_sx8AnjRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zTOSFTWS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_E6xkDigS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSczPhK6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BULf5Hsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TZTUeKpU, HV_BINOP_MULTIPLY, 0, m, &cBinop_TZTUeKpU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TZTUeKpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8Q0ppjS0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_p3BRFhk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FNOxbhKG, 0, m, &cVar_FNOxbhKG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RuYHqKoc, 0, m, &cVar_RuYHqKoc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1LEO2byc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BULf5Hsz, HV_BINOP_DIVIDE, 1, m, &cBinop_BULf5Hsz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_X9ZwfcJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RuYHqKoc, 0, m, &cVar_RuYHqKoc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8fIcfP0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FNOxbhKG, 0, m, &cVar_FNOxbhKG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ef3GSH23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lvhWdRPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UatzpFj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jBqIad4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n3U3kXog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_itKM7yf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iRmWU4si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vaRZMWfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7tFHIjdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YzcBkNh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nEm829Tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zTOSFTWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pSczPhK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X9ZwfcJc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8fIcfP0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xWcXd1um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_b7Wboe3S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PAI4VYSO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_dcZZCXlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_b7Wboe3S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PAI4VYSO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_frk5YCaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_b7Wboe3S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PAI4VYSO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rBi7i4dL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_b7Wboe3S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PAI4VYSO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2ePG1RTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_b7Wboe3S_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PAI4VYSO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Qphcx69H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_tnr1Ubcv, 0, m, &cVar_tnr1Ubcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JWEIbQ8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_zyAeuppi, 0, m, &cVar_zyAeuppi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h8oJMC1y, 0, m, &cVar_h8oJMC1y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fnhtHAQA, 0, m, &cVar_fnhtHAQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iupqfkhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6cVSm3XH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DrHoDIlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6cVSm3XH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_ga0DBatE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6ZDjpTJT, 0, m, &cVar_6ZDjpTJT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uX2wIt5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sWQ1u0dg, 0, m, &cVar_sWQ1u0dg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i8xjt6qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EVMHVwHC, 0, m, &cVar_EVMHVwHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cQR1Arck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6cVSm3XH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5AocJUtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_6cVSm3XH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_7Os08LIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_llUbHqBQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_84jjLDL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_llUbHqBQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_nadgPKzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NhsUxSOv, 0, m, &cVar_NhsUxSOv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a2PvyOAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N4tih93S, 0, m, &cVar_N4tih93S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qNDraDSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oLCD6zst, 0, m, &cVar_oLCD6zst_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CpujEtEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_llUbHqBQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_idNdUTBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_llUbHqBQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1vy4OKdJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KctIUay8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fOMVGEvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KctIUay8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_E9vdsmNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yaZBfMoA, 0, m, &cVar_yaZBfMoA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c8pzQJm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_07hesC6E, 0, m, &cVar_07hesC6E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_udfLVvts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vDByRBCZ, 0, m, &cVar_vDByRBCZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OJkRaUIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KctIUay8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YDVr1jCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_KctIUay8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_6LrdmchT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R23fXq5o, 0, m, &cVar_R23fXq5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0X6IIUai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DwbPky6R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_06JfQP61_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ffB7KE2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dCHdK8qx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9CCY94rh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9CCY94rh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s4AwjXm8, 0, m, &cVar_s4AwjXm8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dCHdK8qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iMrWqOsq, 1, m, &cIf_iMrWqOsq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DwbPky6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IPn2yIfd, 1, m, &cIf_IPn2yIfd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_06JfQP61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R23fXq5o, 0, m, &cVar_R23fXq5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x8GsenMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CowyJzkV, 0, m, &cVar_CowyJzkV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jSq1NmVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CCNtlXTG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e9ce8FOy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l9zhszfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c1E04LnF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_70MA3cDV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c1E04LnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PtL9VEmS, 1, m, &cIf_PtL9VEmS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_70MA3cDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cbbdjo1A, 0, m, &cVar_Cbbdjo1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e9ce8FOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CowyJzkV, 0, m, &cVar_CowyJzkV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CCNtlXTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_09DjQoN6, 1, m, &cIf_09DjQoN6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tFHqFCKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VPRQAEvi, 0, m, &cVar_VPRQAEvi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pu2cKekL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5CmtwEU3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EzsGKvmW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PnVc4aDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zDPaojMg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_by9qI1Kz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_by9qI1Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6bm554UU, 0, m, &cVar_6bm554UU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zDPaojMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4h1IrHQd, 1, m, &cIf_4h1IrHQd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5CmtwEU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nrvgTTcx, 1, m, &cIf_nrvgTTcx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EzsGKvmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VPRQAEvi, 0, m, &cVar_VPRQAEvi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mJS271um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zyAeuppi, 0, m, &cVar_zyAeuppi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_w8whdEiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h8oJMC1y, 0, m, &cVar_h8oJMC1y_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_oGRup8gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fnhtHAQA, 0, m, &cVar_fnhtHAQA_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_e5dDX53L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8vis7q5m, 0, m, &cVar_8vis7q5m_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qC39zOB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GQF06SUJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OZkBGwVf_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nlb5PYEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gf89nSh4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fYjD5gGR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sdf1VcfR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WQrU5MVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QlW9VlFh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nTfbjxID_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kszPgf0N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FyfxgPdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rSiLAiZd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JKEOd0pc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C1ckdgUg_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dYEe7G67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UmIgD4sf_sendMessage(_c, 0, m);
  cMsg_Wye0PkbZ_sendMessage(_c, 0, m);
  cMsg_wqGRlket_sendMessage(_c, 0, m);
  cMsg_xWqiPCq2_sendMessage(_c, 0, m);
  cMsg_1demcSfT_sendMessage(_c, 0, m);
  cMsg_UElH4Jfc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fwVJ7RiH, 0, m, &cVar_fwVJ7RiH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8vis7q5m, 0, m, &cVar_8vis7q5m_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XBgnaUgW, 0, m, &cVar_XBgnaUgW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h1ohX5rw, 0, m, &cVar_h1ohX5rw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dsntRGu8, 0, m, &cVar_dsntRGu8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P0w80moO, 0, m, &cVar_P0w80moO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RtKyE3Sq, 0, m, &cVar_RtKyE3Sq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8T1F2TDL, 0, m, &cVar_8T1F2TDL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_05sfXSSr, 0, m, &cVar_05sfXSSr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c67VUYzo, 0, m, &cVar_c67VUYzo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3uMEvcL2, 0, m, &cVar_3uMEvcL2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kwAn47Zz, 0, m, &cVar_kwAn47Zz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v1kMfpVX, 0, m, &cVar_v1kMfpVX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ou6tJvnX, 0, m, &cVar_Ou6tJvnX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WFLJSEIN, 0, m, &cVar_WFLJSEIN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rHyNkUmU, 0, m, &cVar_rHyNkUmU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YYNGggqP, 0, m, &cVar_YYNGggqP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FBbQ6xj4, 0, m, &cVar_FBbQ6xj4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Tp6FzV66, 0, m, &cVar_Tp6FzV66_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rByvce28, 0, m, &cVar_rByvce28_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_48q4yCNm, 0, m, &cVar_48q4yCNm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AUNQW6dK, 0, m, &cVar_AUNQW6dK_sendMessage);
  cMsg_z7oOGZ7Y_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_spGo2FR3, 0, m, &cVar_spGo2FR3_sendMessage);
  cMsg_OTTYiGtU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sqR7zGZQ, 0, m, &cVar_sqR7zGZQ_sendMessage);
  cMsg_XGXCwmSs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CgSVQmn9, 0, m, &cVar_CgSVQmn9_sendMessage);
  cMsg_qnAIM47r_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DezhKF6R, 0, m, &cVar_DezhKF6R_sendMessage);
  cMsg_gJKDR1mf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6shtn7IU, 0, m, &cVar_6shtn7IU_sendMessage);
  cMsg_BlcFFNxd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_A0XliZu3, 0, m, &cVar_A0XliZu3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BBRviKV3, 0, m, &cVar_BBRviKV3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CtHHBQmV, 0, m, &cVar_CtHHBQmV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7FKMgrML, 0, m, &cVar_7FKMgrML_sendMessage);
  cMsg_nEQILuNA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tG8KpjXW, 0, m, &cVar_tG8KpjXW_sendMessage);
  cMsg_IiCVVgNW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MnglVKN1, 0, m, &cVar_MnglVKN1_sendMessage);
  cMsg_oGZ9afmC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xVGmRWBA, 0, m, &cVar_xVGmRWBA_sendMessage);
  cMsg_f2czuKds_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_neS0EHoA, 0, m, &cVar_neS0EHoA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4V59JlPb, 0, m, &cVar_4V59JlPb_sendMessage);
  cMsg_oRM0gaAt_sendMessage(_c, 0, m);
  cMsg_ug9XVbRi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DMHRrMQq, 0, m, &cVar_DMHRrMQq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mZHCjmU9, 0, m, &cVar_mZHCjmU9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KzPuhE96, 0, m, &cVar_KzPuhE96_sendMessage);
  cMsg_jOtLh9dx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uxgWOwXM, 0, m, &cVar_uxgWOwXM_sendMessage);
  cMsg_AWtQ25Wi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VUL8sCaa, 0, m, &cVar_VUL8sCaa_sendMessage);
  cMsg_YhidmvkN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aIYCJqQk, 0, m, &cVar_aIYCJqQk_sendMessage);
  cMsg_AbbQ681a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YrgZFoYY, 0, m, &cVar_YrgZFoYY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XzNNo5RU, 0, m, &cVar_XzNNo5RU_sendMessage);
  cMsg_Xn21O91n_sendMessage(_c, 0, m);
  cMsg_aboNlKgf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2CXvN2eC, 0, m, &cVar_2CXvN2eC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MHprr7mE, 0, m, &cVar_MHprr7mE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GjAneATj, 0, m, &cVar_GjAneATj_sendMessage);
  cMsg_Ldks9WMo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_82AhKPIj, 0, m, &cVar_82AhKPIj_sendMessage);
  cMsg_PvtMhvYn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_O2M1j7XT, 0, m, &cVar_O2M1j7XT_sendMessage);
  cMsg_jSUxIPvP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cJ1mKNky, 0, m, &cVar_cJ1mKNky_sendMessage);
  cMsg_7rYngTTO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JEv7cZTL, 0, m, &cVar_JEv7cZTL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tXMnp2tc, 0, m, &cVar_tXMnp2tc_sendMessage);
  cMsg_flsKzghA_sendMessage(_c, 0, m);
  cMsg_gPGshhmu_sendMessage(_c, 0, m);
  cMsg_JWEIbQ8N_sendMessage(_c, 0, m);
  cMsg_Qphcx69H_sendMessage(_c, 0, m);
  cMsg_lwCJ6uzq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xLJKtZYB, 0, m, &cVar_xLJKtZYB_sendMessage);
  cMsg_OCugrV3Y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_g9D7nTb0, 0, m, &cTabhead_g9D7nTb0_sendMessage);
  cMsg_veB9BQkL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_IoOkxZy6, 0, m, &cVar_IoOkxZy6_sendMessage);
  cMsg_DWcTHSyY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_uEvGtxQJ, 0, m, &cTabhead_uEvGtxQJ_sendMessage);
  cMsg_IWuD6iHE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pcqH1HmT, 0, m, &cVar_pcqH1HmT_sendMessage);
  cMsg_46KkKBG9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_k7c2qPjO, 0, m, &cTabhead_k7c2qPjO_sendMessage);
  cMsg_RMI9qqkN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cdd5NsBa, 0, m, &cVar_cdd5NsBa_sendMessage);
  cMsg_vfNgblhT_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4A8SDNXc, 0, m, &cTabhead_4A8SDNXc_sendMessage);
  cMsg_C4SzMZ0E_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_17NCJ1Qe, 0, m, &cVar_17NCJ1Qe_sendMessage);
  cMsg_dLdUYz7C_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_tmhNnqU2, 0, m, &cTabhead_tmhNnqU2_sendMessage);
  cMsg_FsD9SGp2_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oyf3QO4Y, 0, m, &cVar_oyf3QO4Y_sendMessage);
  cMsg_hte53JU8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hJbtUJxh, 0, m, &cTabhead_hJbtUJxh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_LRo7Ipbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PDsEvA2F, HV_BINOP_MULTIPLY, 0, m, &cBinop_PDsEvA2F_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wLu6Kumm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lsxf6UKN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_efYCcPpN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_g4jLuJO2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7t5IgWEl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WEWC6vLT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XASHvAIO_sendMessage);
  cMsg_s31DheaC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_ooF0SNmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZDDszYZs, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZDDszYZs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_eczcJID0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_iaRgc0cP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dQxoFvjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6uzXSxlC, HV_BINOP_MULTIPLY, 1, m, &cBinop_6uzXSxlC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Fd7m82Ll_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_lxRkkHQh_sendMessage);
  cMsg_KpOfNB5W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_eSByEXND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0PVgaYES, HV_BINOP_MULTIPLY, 0, m, &cBinop_0PVgaYES_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UJUiOrll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gSXBTzlo_sendMessage(_c, 0, m);
  cMsg_UqwqGbDq_sendMessage(_c, 0, m);
  cMsg_Gtr87bYq_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_lunIDHvp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YLJrSkUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gycJ3cXw_sendMessage);
  cMsg_pkfcohZz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_0ihn8ChK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dsntRGu8, 0, m, &cVar_dsntRGu8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_105AVEkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pcSppMxX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JUBK6eCD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wVgKrjDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eEWR5aec_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BGgdiRIp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nIYwy2eV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_CnQbqLCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0O2Yewpl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y7oDZHIb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GgqdP2xC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8GOBq7RD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lYHPigvt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ykDlqg5o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_krXjm1bT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vmvdUYmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hC8KzAfh, HV_BINOP_MULTIPLY, 0, m, &cBinop_hC8KzAfh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6C7agtLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jSKofDGr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4hR9nDFc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NxOPSj61_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ZWQo7Lkn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1vqjxvL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_H0CzCmRT_sendMessage);
  cMsg_V5uClCEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_UuJIszpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPgmiaYO, HV_BINOP_MULTIPLY, 0, m, &cBinop_JPgmiaYO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jSiCIRGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_opyx7ubJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8fuAb2Sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XOenZNm5, HV_BINOP_MULTIPLY, 1, m, &cBinop_XOenZNm5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_egIFnse8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7mM8VFIO_sendMessage);
  cMsg_CB6P1fSf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_BfZxmlGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JErNPv7o, HV_BINOP_MULTIPLY, 0, m, &cBinop_JErNPv7o_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mdrdIGC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e0rtb7g6_sendMessage(_c, 0, m);
  cMsg_0fJ33AOk_sendMessage(_c, 0, m);
  cMsg_EyigH7jv_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_hTgJQckI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_apcANYBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cHovdH32_sendMessage);
  cMsg_FJdo74YL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_btsDG1tZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tnr1Ubcv, 0, m, &cVar_tnr1Ubcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_b1F0LfBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ga0DBatE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_92SaExm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_uX2wIt5v_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_vmMF6BXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_i8xjt6qv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2Zos71Fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nadgPKzq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FdBOCn5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_a2PvyOAd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_BugdylM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_E9vdsmNj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_yCivyehN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_c8pzQJm8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Os7sK6sR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_udfLVvts_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2Jgh5RS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_qNDraDSX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HrM5fwGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LQSNRBRE, HV_BINOP_MULTIPLY, 1, m, &cBinop_LQSNRBRE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tSbZTtV1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EAGNSJ0h, HV_BINOP_MULTIPLY, 1, m, &cBinop_EAGNSJ0h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NanohraL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_onbMeAjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_J1JeJTku, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wO4aQyHW, m);
}

void Heavy_WSTD_DL3Y::cReceive_Uyxy75y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lBYNyz7v_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lShH9u6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_DB2Q4jnC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mLMfzuBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D8VCG4sC, HV_BINOP_MULTIPLY, 1, m, &cBinop_D8VCG4sC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RyEijl8y_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ugp6S1MG, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ugp6S1MG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SFKSfCqp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uoLKfGzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YpkR6roQ, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_B01C8WzZ, m);
}

void Heavy_WSTD_DL3Y::cReceive_zR6v04j2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vtq9XRNk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mPh1lRLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_dq4aJD8N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1NZrvZDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ghd1wTsN, HV_BINOP_MULTIPLY, 1, m, &cBinop_ghd1wTsN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GRpRkIBq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VewR3gJE, HV_BINOP_MULTIPLY, 1, m, &cBinop_VewR3gJE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ULAoPm1G_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gRxaeJAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4KXcErRU, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lq9Hohxa, m);
}

void Heavy_WSTD_DL3Y::cReceive_uKCJR26i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IgPwZqxw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_x13ud81Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bgIVQUql_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aIaky8y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_s4AwjXm8, 0, m, &cVar_s4AwjXm8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_XI2d8j6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0iOdc2E1, 0, m, &cVar_0iOdc2E1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kOw5lEs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SFttxh9i, 0, m, &cVar_SFttxh9i_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Zx1gsONL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cbbdjo1A, 0, m, &cVar_Cbbdjo1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_L0rRhCSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6bm554UU, 0, m, &cVar_6bm554UU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7EMQTVfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d7Leqv0V, 0, m, &cVar_d7Leqv0V_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_LppNwLpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tcdhWlqF, 0, m, &cVar_tcdhWlqF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bamSgTOS, 0, m, &cVar_bamSgTOS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V6TBUuQE, 0, m, &cVar_V6TBUuQE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SdcqfYb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YAkRztSv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_DymIz6rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vR3JrWf4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_1CxV2LuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RKRM3S28_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_Nr778c4c, VOf(Bf0));
    __hv_line_f(&sLine_bqJlyGNs, VOf(Bf1));
    __hv_line_f(&sLine_5O11rrrH, VOf(Bf2));
    __hv_line_f(&sLine_KKhe5vKv, VOf(Bf3));
    __hv_line_f(&sLine_dSd2evSE, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_8lEel2PL, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5UJgTd56, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_jiGvYF38, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_qbklHF1L, VOf(Bf1));
    __hv_line_f(&sLine_Vp3laZPL, VOf(Bf0));
    __hv_line_f(&sLine_OgbO87I9, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_xnnPQN0C, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_85VSfsXc, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_S5cXmYtT, VOf(Bf5));
    __hv_line_f(&sLine_LyK7fv0B, VOf(Bf1));
    __hv_line_f(&sLine_qZ2Ecf5U, VOf(Bf2));
    __hv_line_f(&sLine_NntBvcpW, VOf(Bf4));
    __hv_line_f(&sLine_MrRX6NRp, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_LCIsYrVb, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_np3EeWEt, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_fljJ44sK, VOf(Bf6));
    __hv_line_f(&sLine_9wupr0VR, VOf(Bf2));
    __hv_line_f(&sLine_O5NGGsSd, VOf(Bf1));
    __hv_line_f(&sLine_2zQjHyvH, VOf(Bf5));
    __hv_line_f(&sLine_jRpmTe22, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_bhOdl786, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_hpcPsqTt, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_GUQqJU4s, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_kMjfsphY, VOf(Bf2));
    __hv_line_f(&sLine_u40IXIkt, VOf(Bf6));
    __hv_line_f(&sLine_dYPLvLZs, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_G79NTCJf, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_aDaQtmY7, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Ki70oiwL, VOf(Bf8));
    __hv_line_f(&sLine_32xyaus1, VOf(Bf2));
    __hv_line_f(&sLine_ypmsRwLx, VOf(Bf1));
    __hv_line_f(&sLine_DbB5wF6s, VOf(Bf7));
    __hv_line_f(&sLine_Mujp5oLE, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_3c92ljaG, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_cSyiPhTP, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_SiHkTrto, VOf(Bf9));
    __hv_tabread_f(&sTabread_OpcZ7DJ1, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_PJfgcWfp, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_vhIaCNiQ, VOf(Bf9));
    __hv_tabread_f(&sTabread_xsaDvBh2, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_4eqeo5B2, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_IB2p0NoO, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_vbAXegNQ, VOf(Bf3));
    __hv_rpole_f(&sRPole_MCfKTWy5, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_bvCgA808, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_pSwUZzbP, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_kWtHoB3q, VIf(Bf3));
    __hv_varread_f(&sVarf_2yQTmld7, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_f6dpVIu2, VOf(Bf5));
    __hv_rpole_f(&sRPole_VtAMkNya, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_CgtU2iXy, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_lEnoaVt5, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_w2pURm5T, VIf(Bf5));
    __hv_varread_f(&sVarf_J1JeJTku, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_9AMDrpsb, VOf(Bf1));
    __hv_varread_f(&sVarf_wO4aQyHW, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_tYY3DqE4, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_kJHkpQmY, VOf(Bf1));
    __hv_varread_f(&sVarf_MaOUQvBj, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_qOtrtMXM, VOf(Bf1));
    __hv_rpole_f(&sRPole_b0No4I6s, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_mUEGhEzw, VIf(Bf8), &sEnv_mUEGhEzw_sendMessage);
    __hv_varread_f(&sVarf_TyGI0rbR, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_lO4qK856, VOf(Bf1));
    __hv_rpole_f(&sRPole_NapJOkmE, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_IB2p0NoO, VIf(Bf1));
    __hv_line_f(&sLine_rMRI8Z8T, VOf(Bf1));
    __hv_line_f(&sLine_89DJZMCn, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_5j3oY51H, VOf(Bf1));
    __hv_varread_f(&sVarf_UMA2RpvU, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_pvv8SV8e, VOf(Bf1));
    __hv_rpole_f(&sRPole_NDokYEo6, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_OwubAB32, VIf(Bf8), &sEnv_OwubAB32_sendMessage);
    __hv_varread_f(&sVarf_Noj6rC6D, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_QF7Oh31e, VOf(Bf1));
    __hv_rpole_f(&sRPole_IxniHDuY, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_2yQTmld7, VIf(Bf1));
    __hv_varwrite_f(&sVarf_2ONjKLir, VIf(Bf2));
    __hv_varread_f(&sVarf_2FAlNnCg, VOf(Bf2));
    __hv_varread_f(&sVarf_RaRqaGRw, VOf(Bf1));
    __hv_line_f(&sLine_FrEBcdQy, VOf(Bf8));
    __hv_tabread_f(&sTabread_rGRrRGcl, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_VjRAC79J, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_WNHKtmXy, VOf(Bf8));
    __hv_tabread_f(&sTabread_EascK7nt, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_v4eVq6Rx, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_7b5x3Etu, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_w7yg3Ipd, VOf(Bf2));
    __hv_rpole_f(&sRPole_d0W1xKH5, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_cX4E83Hp, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_y7gZVT4Y, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_liT688eE, VIf(Bf2));
    __hv_varread_f(&sVarf_IBRQwiuw, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_x9LMNPBy, VOf(Bf1));
    __hv_rpole_f(&sRPole_WlwlbXj3, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_0E4HlE3e, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HVsgKAIh, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_HK8kvjCy, VIf(Bf1));
    __hv_varread_f(&sVarf_YpkR6roQ, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_PamYQFoh, VOf(Bf3));
    __hv_varread_f(&sVarf_B01C8WzZ, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_jEJ6ZPTA, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_kACHp35I, VOf(Bf3));
    __hv_varread_f(&sVarf_jewdPNQr, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_SF6GTxrf, VOf(Bf3));
    __hv_rpole_f(&sRPole_md6EVbKO, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_xlSxpIAL, VIf(Bf9), &sEnv_xlSxpIAL_sendMessage);
    __hv_varread_f(&sVarf_7CoGcZtZ, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_yvs9kQZU, VOf(Bf3));
    __hv_rpole_f(&sRPole_c8ZNGOaC, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_7b5x3Etu, VIf(Bf3));
    __hv_line_f(&sLine_mk0ijScY, VOf(Bf3));
    __hv_line_f(&sLine_9EKY0QTN, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_o77aR6p6, VOf(Bf3));
    __hv_varread_f(&sVarf_4cj1tFUE, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5lDLb9pD, VOf(Bf3));
    __hv_rpole_f(&sRPole_Jn1Lfk61, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_wprhuXSZ, VIf(Bf9), &sEnv_wprhuXSZ_sendMessage);
    __hv_varread_f(&sVarf_Bbwr9HIk, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_xWwoqGyP, VOf(Bf3));
    __hv_rpole_f(&sRPole_E6n9NFiY, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_IBRQwiuw, VIf(Bf3));
    __hv_varwrite_f(&sVarf_Ei9pEYN8, VIf(Bf5));
    __hv_varread_f(&sVarf_c9CZFQua, VOf(Bf5));
    __hv_varread_f(&sVarf_9p8oxtoI, VOf(Bf3));
    __hv_line_f(&sLine_D8o1IQ9a, VOf(Bf9));
    __hv_tabread_f(&sTabread_4yWhuYWi, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_9gNqvxe8, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_zcdZoue6, VOf(Bf9));
    __hv_tabread_f(&sTabread_TUNlizre, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_Z9mAmBX2, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_y98UhnWA, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_fS4nUlFd, VOf(Bf5));
    __hv_rpole_f(&sRPole_iMGA2AeB, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_mxQomP5v, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Y4kAoy2n, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_I1NZKkvd, VIf(Bf5));
    __hv_varread_f(&sVarf_ia81Ax2O, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_GmJxjfg8, VOf(Bf3));
    __hv_rpole_f(&sRPole_LDUWhiTk, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Yw98pb13, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_aMDV5QhE, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_lezgKYhk, VIf(Bf3));
    __hv_varread_f(&sVarf_4KXcErRU, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_hePoyE3C, VOf(Bf2));
    __hv_varread_f(&sVarf_lq9Hohxa, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_CQP4Afrq, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dFSQ4B9D, VOf(Bf2));
    __hv_varread_f(&sVarf_8JSg4GyH, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Xd6Pj0ju, VOf(Bf2));
    __hv_rpole_f(&sRPole_1Ko7zf8N, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_sP9ygMXG, VIf(Bf8), &sEnv_sP9ygMXG_sendMessage);
    __hv_varread_f(&sVarf_M5x0W8ZR, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_iYDU982g, VOf(Bf2));
    __hv_rpole_f(&sRPole_qW5LtS1t, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_y98UhnWA, VIf(Bf2));
    __hv_line_f(&sLine_2DiqvxBr, VOf(Bf2));
    __hv_line_f(&sLine_TrYhwPa5, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_sAYI7Glt, VOf(Bf2));
    __hv_varread_f(&sVarf_p7c9rDB8, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_8NArlSep, VOf(Bf2));
    __hv_rpole_f(&sRPole_ev5v9nQC, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_5JrByhW4, VIf(Bf8), &sEnv_5JrByhW4_sendMessage);
    __hv_varread_f(&sVarf_fpRf9nTM, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_FMWm79cD, VOf(Bf2));
    __hv_rpole_f(&sRPole_4GQLR2KN, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_ia81Ax2O, VIf(Bf2));
    __hv_varwrite_f(&sVarf_l7xnBLoT, VIf(Bf1));
    __hv_varwrite_f(&sVarf_kV64asir, VIf(Bf10));
    __hv_varwrite_f(&sVarf_SlezXjgT, VIf(Bf11));
    __hv_varwrite_f(&sVarf_mBzeYffg, VIf(Bf12));
    __hv_varwrite_f(&sVarf_2FAlNnCg, VIf(Bf0));
    __hv_varwrite_f(&sVarf_RaRqaGRw, VIf(Bf6));
    __hv_varwrite_f(&sVarf_c9CZFQua, VIf(Bf4));
    __hv_varwrite_f(&sVarf_9p8oxtoI, VIf(Bf7));
    __hv_varread_f(&sVarf_2ONjKLir, VOf(Bf7));
    __hv_varread_f(&sVarf_Ei9pEYN8, VOf(Bf4));
    __hv_varread_f(&sVarf_l7xnBLoT, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_kV64asir, VOf(Bf6));
    __hv_varread_f(&sVarf_SlezXjgT, VOf(Bf7));
    __hv_varread_f(&sVarf_mBzeYffg, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
